@@ -1,8 +1,10 @@
 from quicktions import Fraction
 
 from . import (
+    _update,
     deprecated,
     enumerate,
+    format,
     get,
     illustrators,
     io,
@@ -13,6 +15,7 @@ from . import (
     makers,
     mutate,
     persist,
+    string,
     wf,
 )
 from ._version import __version__, __version_info__
@@ -63,8 +66,8 @@ from .exceptions import (
     UnboundedTimeIntervalError,
     WellformednessError,
 )
-from .format import FormatSpecification, storage
-from .get import Descendants, Lineage
+from .format import lilypond
+from .get import Lineage
 from .illustrators import illustrate
 from .indicators import (
     Arpeggio,
@@ -162,10 +165,9 @@ from .instruments import (
     Violin,
     Xylophone,
 )
-from .io import graph, play, show
+from .io import graph, show
 from .label import ColorMap
 from .lilypondfile import Block, LilyPondFile
-from .lilypondformat import lilypond
 from .lyproxy import (
     LilyPondContext,
     LilyPondEngraver,
@@ -177,7 +179,6 @@ from .markups import Markup
 from .math import Infinity, NegativeInfinity
 from .meter import Meter, MeterList, MetricAccentKernel
 from .metricmodulation import MetricModulation
-from .new import new
 from .obgc import OnBeatGraceContainer, on_beat_grace_container
 from .overrides import (
     IndexedTweakManager,
@@ -198,20 +199,24 @@ from .parsers import parser
 from .parsers.base import Parser
 from .parsers.parse import parse
 from .pattern import Pattern, PatternTuple
-from .pitch import (
-    Accidental,
-    CompoundOperator,
-    Duplication,
-    Interval,
-    IntervalClass,
+from .pcollections import (
     IntervalClassSegment,
     IntervalClassSet,
-    IntervalClassVector,
     IntervalSegment,
     IntervalSet,
-    IntervalVector,
-    Inversion,
-    Multiplication,
+    PitchClassSegment,
+    PitchClassSet,
+    PitchRange,
+    PitchSegment,
+    PitchSet,
+    Segment,
+    Set,
+    TwelveToneRow,
+)
+from .pitch import (
+    Accidental,
+    Interval,
+    IntervalClass,
     NamedInterval,
     NamedIntervalClass,
     NamedInversionEquivalentIntervalClass,
@@ -225,22 +230,7 @@ from .pitch import (
     Octave,
     Pitch,
     PitchClass,
-    PitchClassSegment,
-    PitchClassSet,
-    PitchClassVector,
-    PitchRange,
-    PitchSegment,
-    PitchSet,
     PitchTyping,
-    PitchVector,
-    Retrograde,
-    Rotation,
-    Segment,
-    Set,
-    SetClass,
-    Transposition,
-    TwelveToneRow,
-    Vector,
 )
 from .ratio import NonreducedRatio, Ratio
 from .score import (
@@ -266,17 +256,8 @@ from .score import (
     Tuplet,
     Voice,
 )
-from .segmentmaker import SegmentMaker
-from .selection import (
-    DurationInequality,
-    Inequality,
-    LengthInequality,
-    LogicalTie,
-    PitchInequality,
-    Selection,
-    select,
-)
-from .sequence import Sequence
+from .select import LogicalTie, Selection
+from .setclass import SetClass
 from .spanners import (
     beam,
     glissando,
@@ -290,23 +271,9 @@ from .spanners import (
     tie,
     trill_spanner,
 )
-from .string import String
 from .tag import Line, Tag, activate, deactivate
-from .templates import (
-    GroupedRhythmicStavesScoreTemplate,
-    GroupedStavesScoreTemplate,
-    ScoreTemplate,
-    StringOrchestraScoreTemplate,
-    StringQuartetScoreTemplate,
-)
 from .timespan import OffsetCounter, Timespan, TimespanList
-from .typedcollections import (
-    TypedCollection,
-    TypedCounter,
-    TypedFrozenset,
-    TypedList,
-    TypedTuple,
-)
+from .typedcollections import TypedCollection, TypedFrozenset, TypedList, TypedTuple
 from .typings import (
     DurationSequenceTyping,
     DurationTyping,
@@ -370,7 +337,6 @@ __all__ = [
     "ColorMap",
     "Comparison",
     "Component",
-    "CompoundOperator",
     "Configuration",
     "Container",
     "Context",
@@ -381,12 +347,9 @@ __all__ = [
     "ContrabassSaxophone",
     "Contrabassoon",
     "CyclicTuple",
-    "Descendants",
     "Down",
     "DrumNoteHead",
-    "Duplication",
     "Duration",
-    "DurationInequality",
     "DurationSequenceTyping",
     "DurationTyping",
     "Dynamic",
@@ -397,13 +360,10 @@ __all__ = [
     "FilesystemState",
     "Flute",
     "ForbidUpdate",
-    "FormatSpecification",
     "Fraction",
     "FrenchHorn",
     "Glissando",
     "Glockenspiel",
-    "GroupedRhythmicStavesScoreTemplate",
-    "GroupedStavesScoreTemplate",
     "Guitar",
     "Harp",
     "Harpsichord",
@@ -411,7 +371,6 @@ __all__ = [
     "ImpreciseMetronomeMarkError",
     "IndexedTweakManager",
     "IndexedTweakManagers",
-    "Inequality",
     "Infinity",
     "Instrument",
     "IntegerPair",
@@ -421,18 +380,14 @@ __all__ = [
     "IntervalClass",
     "IntervalClassSegment",
     "IntervalClassSet",
-    "IntervalClassVector",
     "IntervalSegment",
     "IntervalSet",
-    "IntervalVector",
-    "Inversion",
     "KeyCluster",
     "KeySignature",
     "LaissezVibrer",
     "Leaf",
     "LeafMaker",
     "Left",
-    "LengthInequality",
     "Less",
     "LilyPondContext",
     "LilyPondEngraver",
@@ -461,7 +416,6 @@ __all__ = [
     "Mode",
     "More",
     "MultimeasureRest",
-    "Multiplication",
     "Multiplier",
     "NamedInterval",
     "NamedIntervalClass",
@@ -504,13 +458,10 @@ __all__ = [
     "PitchClass",
     "PitchClassSegment",
     "PitchClassSet",
-    "PitchClassVector",
-    "PitchInequality",
     "PitchRange",
     "PitchSegment",
     "PitchSet",
     "PitchTyping",
-    "PitchVector",
     "ProgressIndicator",
     "Prototype",
     "Ratio",
@@ -521,16 +472,11 @@ __all__ = [
     "Repeat",
     "RepeatTie",
     "Rest",
-    "Retrograde",
     "Right",
-    "Rotation",
     "SchemeParserFinishedError",
     "Score",
-    "ScoreTemplate",
     "Segment",
-    "SegmentMaker",
     "Selection",
-    "Sequence",
     "Set",
     "SetClass",
     "SettingInterface",
@@ -561,10 +507,7 @@ __all__ = [
     "StopSlur",
     "StopTextSpan",
     "StopTrillSpan",
-    "String",
     "StringNumber",
-    "StringOrchestraScoreTemplate",
-    "StringQuartetScoreTemplate",
     "Strings",
     "Tag",
     "TemporaryDirectory",
@@ -577,7 +520,6 @@ __all__ = [
     "Timer",
     "Timespan",
     "TimespanList",
-    "Transposition",
     "TremoloContainer",
     "Trumpet",
     "Tuba",
@@ -586,13 +528,11 @@ __all__ = [
     "TweakInterface",
     "TwelveToneRow",
     "TypedCollection",
-    "TypedCounter",
     "TypedFrozenset",
     "TypedList",
     "TypedTuple",
     "UnboundedTimeIntervalError",
     "Up",
-    "Vector",
     "VerticalAlignment",
     "VerticalMoment",
     "Vibraphone",
@@ -604,6 +544,7 @@ __all__ = [
     "Xylophone",
     "__version__",
     "__version_info__",
+    "_update",
     "activate",
     "annotate",
     "attach",
@@ -638,7 +579,6 @@ __all__ = [
     "lyenv",
     "makers",
     "mutate",
-    "new",
     "on_beat_grace_container",
     "ottava",
     "override",
@@ -647,12 +587,11 @@ __all__ = [
     "persist",
     "phrasing_slur",
     "piano_pedal",
-    "play",
     "select",
     "setting",
     "show",
     "slur",
-    "storage",
+    "string",
     "text_spanner",
     "tie",
     "trill_spanner",
