@@ -89,7 +89,7 @@ def _get_measure_start_offsets(component):
     pairs.append(dummy_last_pair)
     measure_start_offsets = []
     at_first_measure = True
-    for current_pair, next_pair in _sequence.Sequence(pairs).nwise():
+    for current_pair, next_pair in _sequence.nwise(pairs):
         current_start_offset, current_time_signature = current_pair
         next_start_offset, next_time_signature = next_pair
         measure_start_offset = current_start_offset
@@ -178,7 +178,7 @@ def _make_metronome_mark_map(root):
     score_stop_offset = max(all_stop_offsets)
     timespans = _timespan.TimespanList()
     clocktime_start_offset = _duration.Offset(0)
-    for left, right in _sequence.Sequence(pairs).nwise(wrapped=True):
+    for left, right in _sequence.nwise(pairs, wrapped=True):
         metronome_mark = left[-1]
         start_offset = left[0]
         stop_offset = right[0]
@@ -213,8 +213,7 @@ def _to_measure_number(component, measure_start_offsets):
             return measure_number
     measure_start_offsets = measure_start_offsets[:]
     measure_start_offsets.append(_math.Infinity())
-    pairs = _sequence.Sequence(measure_start_offsets)
-    pairs = pairs.nwise()
+    pairs = _sequence.nwise(measure_start_offsets)
     for measure_index, pair in enumerate(pairs):
         if pair[0] <= component_start_offset < pair[-1]:
             measure_number = measure_index + 1
@@ -352,8 +351,8 @@ def _update_component_offsets(component):
         stop_offset = start_offset + component._get_duration()
     component._start_offset = start_offset
     component._stop_offset = stop_offset
-    component._timespan._start_offset = start_offset
-    component._timespan._stop_offset = stop_offset
+    component._timespan.start_offset = start_offset
+    component._timespan.stop_offset = stop_offset
 
 
 def _update_measure_numbers(component):
@@ -366,18 +365,16 @@ def _update_measure_numbers(component):
 
 def _update_now(component, offsets=False, offsets_in_seconds=False, indicators=False):
     assert offsets or offsets_in_seconds or indicators
-    if component._is_forbidden_to_update:
-        return
-    parentage = _parentage.Parentage(component)
-    for parent in parentage:
-        if parent._is_forbidden_to_update:
+    parentage = component._get_parentage()
+    for component_ in parentage:
+        if component_._is_forbidden_to_update:
             return
-        (
-            offsets_are_current,
-            indicators_are_current,
-            offsets_in_seconds_are_current,
-        ) = _get_score_tree_state_flags(parentage)
-    root = parentage.root
+    (
+        offsets_are_current,
+        indicators_are_current,
+        offsets_in_seconds_are_current,
+    ) = _get_score_tree_state_flags(parentage)
+    root = parentage[-1]
     if offsets and not offsets_are_current:
         _update_all_offsets(root)
     if offsets_in_seconds and not offsets_in_seconds_are_current:
