@@ -2,10 +2,9 @@ import copy
 import importlib
 import typing
 
-from . import _inspect
+from . import _inspect, _update
 from . import duration as _duration
 from . import exceptions as _exceptions
-from . import format as _format
 from . import score as _score
 from . import tag as _tag
 
@@ -19,14 +18,8 @@ class Wrapper:
         >>> component = abjad.Note("c'4")
         >>> articulation = abjad.Articulation("accent", direction=abjad.Up)
         >>> abjad.attach(articulation, component)
-        >>> wrapper = abjad.get.wrapper(component)
-
-        >>> string = abjad.storage(wrapper)
-        >>> print(string)
-        abjad.Wrapper(
-            indicator=Articulation(name='accent', direction=Up, tweaks=None),
-            tag=abjad.Tag(),
-            )
+        >>> abjad.get.wrapper(component)
+        Wrapper(annotation=None, context=None, deactivate=False, indicator=Articulation(name='accent', direction=Up, tweaks=None), synthetic_offset=None, tag=Tag())
 
     ..  container:: example
 
@@ -96,7 +89,7 @@ class Wrapper:
         check_duplicate_indicator=False,
         component=None,
         context: str = None,
-        deactivate: bool = None,
+        deactivate: bool = False,
         indicator: typing.Any = None,
         synthetic_offset: int = None,
         tag: typing.Union[str, _tag.Tag] = None,
@@ -108,8 +101,7 @@ class Wrapper:
         if component is not None:
             assert isinstance(component, _score.Component), repr(component)
         self._component = component
-        if deactivate is not None:
-            deactivate = bool(deactivate)
+        deactivate = bool(deactivate)
         if context is not None:
             assert isinstance(context, str), repr(context)
         self._context = context
@@ -190,14 +182,8 @@ class Wrapper:
             }
 
             >>> leaf = old_staff[0]
-            >>> wrapper = abjad.get.wrapper(leaf)
-            >>> string = abjad.storage(wrapper)
-            >>> print(string)
-            abjad.Wrapper(
-                context='Staff',
-                indicator=Clef(name='alto', hide=False),
-                tag=abjad.Tag('RED:M1'),
-                )
+            >>> abjad.get.wrapper(leaf)
+            Wrapper(annotation=None, context='Staff', deactivate=False, indicator=Clef(name='alto', hide=False), synthetic_offset=None, tag=Tag('RED:M1'))
 
             >>> new_staff = abjad.mutate.copy(old_staff)
             >>> string = abjad.lilypond(new_staff, tags=True)
@@ -214,14 +200,8 @@ class Wrapper:
             }
 
             >>> leaf = new_staff[0]
-            >>> wrapper = abjad.get.wrapper(leaf)
-            >>> string = abjad.storage(wrapper)
-            >>> print(string)
-            abjad.Wrapper(
-                context='Staff',
-                indicator=Clef(name='alto', hide=False),
-                tag=abjad.Tag('RED:M1'),
-                )
+            >>> abjad.get.wrapper(leaf)
+            Wrapper(annotation=None, context='Staff', deactivate=False, indicator=Clef(name='alto', hide=False), synthetic_offset=None, tag=Tag('RED:M1'))
 
         ..  container:: example
 
@@ -248,15 +228,8 @@ class Wrapper:
             }
 
             >>> leaf = old_staff[0]
-            >>> wrapper = abjad.get.wrapper(leaf)
-            >>> string = abjad.storage(wrapper)
-            >>> print(string)
-            abjad.Wrapper(
-                context='Staff',
-                deactivate=True,
-                indicator=Clef(name='alto', hide=False),
-                tag=abjad.Tag('RED:M1'),
-                )
+            >>> abjad.get.wrapper(leaf)
+            Wrapper(annotation=None, context='Staff', deactivate=True, indicator=Clef(name='alto', hide=False), synthetic_offset=None, tag=Tag('RED:M1'))
 
             >>> new_staff = abjad.mutate.copy(old_staff)
             >>> string = abjad.lilypond(new_staff, tags=True)
@@ -273,15 +246,8 @@ class Wrapper:
             }
 
             >>> leaf = new_staff[0]
-            >>> wrapper = abjad.get.wrapper(leaf)
-            >>> string = abjad.storage(wrapper)
-            >>> print(string)
-            abjad.Wrapper(
-                context='Staff',
-                deactivate=True,
-                indicator=Clef(name='alto', hide=False),
-                tag=abjad.Tag('RED:M1'),
-                )
+            >>> abjad.get.wrapper(leaf)
+            Wrapper(annotation=None, context='Staff', deactivate=True, indicator=Clef(name='alto', hide=False), synthetic_offset=None, tag=Tag('RED:M1'))
 
         Copies all properties except component.
 
@@ -328,9 +294,18 @@ class Wrapper:
 
     def __repr__(self) -> str:
         """
-        Gets interpreter representation.
+        Gets repr.
         """
-        return _format.get_repr(self)
+        parameters = f"""
+            annotation={self.annotation!r},
+            context={self.context!r},
+            deactivate={self.deactivate!r},
+            indicator={self.indicator!r},
+            synthetic_offset={self.synthetic_offset!r},
+            tag={self.tag!r}
+        """
+        parameters = " ".join(parameters.split())
+        return f"{type(self).__name__}({parameters})"
 
     ### PRIVATE METHODS ###
 
@@ -393,7 +368,7 @@ class Wrapper:
 
     def _get_effective_context(self):
         if self.component is not None:
-            self.component._update_now(indicators=True)
+            _update._update_now(self.component, indicators=True)
         return self._effective_context
 
     def _get_format_pieces(self):
@@ -421,19 +396,6 @@ class Wrapper:
         result = [rf"%%% {_} %%%" for _ in result]
         return result
 
-    def _get_format_specification(self):
-        keywords = [
-            "annotation",
-            "context",
-            "deactivate",
-            "indicator",
-            "synthetic_offset",
-            "tag",
-        ]
-        return _format.FormatSpecification(
-            storage_format_keyword_names=keywords,
-        )
-
     def _unbind_component(self):
         if self._component is not None and self in self._component._wrappers:
             self._component._wrappers.remove(self)
@@ -491,10 +453,10 @@ class Wrapper:
                 break
         if wrapper.indicator == self.indicator and context is not wrapper_context:
             return
-        message = f"\n\nCan not attach ...\n\n{_format.storage(self)}\n\n..."
+        message = f"\n\nCan not attach ...\n\n{repr(self)}\n\n..."
         message += f" to {repr(component)}"
         message += f" in {getattr(context, 'name', None)} because ..."
-        message += f"\n\n{_format.storage(wrapper)}\n\n"
+        message += f"\n\n{repr(wrapper)}\n\n"
         message += "... is already attached"
         if component is wrapper.component:
             message += " to the same leaf."
@@ -548,7 +510,7 @@ class Wrapper:
         return self._context
 
     @property
-    def deactivate(self) -> typing.Optional[bool]:
+    def deactivate(self) -> bool:
         """
         Is true when wrapper deactivates tag.
         """
@@ -703,7 +665,7 @@ def attach(  # noqa: 302
     target,
     check_duplicate_indicator=False,
     context=None,
-    deactivate=None,
+    deactivate=False,
     do_not_test=None,
     synthetic_offset=None,
     tag=None,
@@ -785,7 +747,7 @@ def attach(  # noqa: 302
                 }
             }
 
-        >>> for leaf in abjad.select(staff).leaves():
+        >>> for leaf in abjad.select.leaves(staff):
         ...     leaf, abjad.get.effective(leaf, abjad.Clef)
         ...
         (Note("c'4"), Clef(name='alto', hide=False))
@@ -904,14 +866,8 @@ def attach(  # noqa: 302
         Returns wrapper when ``wrapper`` is true:
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> wrapper = abjad.attach(abjad.Clef('alto'), staff[0], wrapper=True)
-        >>> string = abjad.storage(wrapper)
-        >>> print(string)
-        abjad.Wrapper(
-            context='Staff',
-            indicator=Clef(name='alto', hide=False),
-            tag=abjad.Tag(),
-            )
+        >>> abjad.attach(abjad.Clef('alto'), staff[0], wrapper=True)
+        Wrapper(annotation=None, context='Staff', deactivate=False, indicator=Clef(name='alto', hide=False), synthetic_offset=None, tag=Tag())
 
     Otherwise returns none.
     """
@@ -1202,7 +1158,7 @@ def detach(argument, target=None, by_id=False):
 
         >>> wrapper = abjad.get.wrappers(staff[0])[0]
         >>> abjad.detach(wrapper, wrapper.component)
-        (Wrapper(context='Staff', indicator=Clef(name='alto', hide=False), tag=Tag()),)
+        (Wrapper(annotation=None, context='Staff', deactivate=False, indicator=Clef(name='alto', hide=False), synthetic_offset=None, tag=Tag()),)
 
         >>> abjad.show(staff) # doctest: +SKIP
 
