@@ -1,4 +1,3 @@
-import abc
 import collections
 import filecmp
 import os
@@ -9,8 +8,8 @@ import sys
 import tempfile
 import time
 
+from . import _update
 from . import configuration as _configuration
-from . import format as _format
 from . import string as _string
 
 configuration = _configuration.Configuration()
@@ -21,39 +20,14 @@ class ContextManager:
     An abstract context manager class.
     """
 
-    ### CLASS VARIABLES ###
-
     __slots__ = ()
-
     _is_abstract = True
 
-    ### INTIALIZER ###
-
-    @abc.abstractmethod
-    def __init__(self):
-        raise NotImplementedError
-
-    ### SPECIAL METHODS ###
-
-    @abc.abstractmethod
-    def __enter__(self):
+    def __repr__(self):
         """
-        Enters context manager.
+        Gets repr.
         """
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    def __exit__(self, exc_type, exc_value, traceback):
-        """
-        Exits context manager.
-        """
-        raise NotImplementedError
-
-    def __repr__(self) -> str:
-        """
-        Gets interpreter representation.
-        """
-        return _format.get_repr(self)
+        return f"<{type(self).__name__}()>"
 
 
 class FilesystemState(ContextManager):
@@ -61,14 +35,10 @@ class FilesystemState(ContextManager):
     Filesystem state context manager.
     """
 
-    ### CLASS VARIABLES ###
-
     __documentation_section__ = "Context managers"
 
     __slots__ = ("_keep", "_remove")
 
-    ### INITIALIZER ###
-
     def __init__(self, keep=None, remove=None):
         keep = keep or []
         assert isinstance(keep, collections.abc.Iterable), repr(keep)
@@ -79,8 +49,6 @@ class FilesystemState(ContextManager):
         remove = tuple([str(_) for _ in remove])
         self._remove = remove
 
-    ### SPECIAL METHODS ###
-
     def __enter__(self):
         """
         Backs up filesystem assets.
@@ -139,8 +107,6 @@ class FilesystemState(ContextManager):
         for path in backup_paths:
             assert not os.path.exists(path), repr(path)
 
-    ### PUBLIC PROPERTIES ###
-
     @property
     def keep(self):
         """
@@ -223,7 +189,7 @@ class ForbidUpdate(ContextManager):
         Returns context manager.
         """
         if self.component is not None:
-            self.component._update_now(offsets=True)
+            _update._update_now(self.component, offsets=True)
             self.component._is_forbidden_to_update = True
         return self
 
@@ -236,7 +202,7 @@ class ForbidUpdate(ContextManager):
         if self.component is not None:
             self.component._is_forbidden_to_update = False
             if self.update_on_exit:
-                self.component._update_now(offsets=True)
+                _update._update_now(self.component, offsets=True)
 
     ### PUBLIC PROPERTIES ###
 
@@ -279,19 +245,13 @@ class NullContextManager(ContextManager):
     A context manager that does nothing.
     """
 
-    ### CLASS VARIABLES ###
-
     __documentation_section__ = "Context managers"
 
     __slots__ = ()
 
-    ### INITIALIZER ###
-
     def __init__(self):
         pass
 
-    ### SPECIAL METHODS ###
-
     def __enter__(self):
         """
         Enters context manager and does nothing.
@@ -441,6 +401,9 @@ class RedirectedStreams(ContextManager):
 
     ..  container:: example
 
+        >>> abjad.RedirectedStreams()
+        <RedirectedStreams()>
+
         >>> from io import StringIO
         >>> string_io = StringIO()
         >>> with abjad.RedirectedStreams(stdout=string_io):
@@ -452,7 +415,6 @@ class RedirectedStreams(ContextManager):
         hello, world!
         <BLANKLINE>
 
-    Redirected streams context manager is immutable.
     """
 
     ### CLASS VARIABLES ###
@@ -509,19 +471,6 @@ class RedirectedStreams(ContextManager):
         """
         return super().__repr__()
 
-    ### PRIVATE METHODS ###
-
-    def _get_format_specification(self):
-        return _format.FormatSpecification(
-            repr_is_bracketed=True,
-            storage_format_is_bracketed=True,
-            storage_format_is_not_indented=True,
-            storage_format_args_values=[],
-            storage_format_keyword_names=[],
-        )
-
-    ### PUBLIC PROPERTIES ###
-
     @property
     def stderr(self):
         """
@@ -856,7 +805,7 @@ class Timer(ContextManager):
 
         Returns string.
         """
-        identifier = _string.String("second").pluralize(int(self.elapsed_time))
+        identifier = _string.string.pluralize("second", int(self.elapsed_time))
         message = f"total time {int(self.elapsed_time)} {identifier} ..."
         return message
 
