@@ -1,22 +1,22 @@
 import copy
+import dataclasses
 
 from . import bind as _bind
-from . import deprecated as _deprecated
 from . import duration as _duration
 from . import enums as _enums
+from . import format as _format
 from . import get as _get
 from . import indicators as _indicators
 from . import iterate as iterate_
 from . import lilypondfile as _lilypondfile
-from . import lilypondformat as _lilypondformat
 from . import makers as _makers
 from . import markups as _markups
 from . import metricmodulation as _metricmodulation
-from . import new as _new
 from . import overrides as _overrides
+from . import pcollections as _pcollections
 from . import pitch as _pitch
 from . import score as _score
-from . import selection as _selection
+from . import select as _select
 from . import spanners as _spanners
 from . import timespan as _timespan
 
@@ -30,7 +30,7 @@ def _illustrate_component(component):
 
 def _illustrate_markup(markup):
     lilypond_file = _lilypondfile.LilyPondFile()
-    markup = _new.new(markup, direction=None)
+    markup = dataclasses.replace(markup, direction=None)
     lilypond_file.items.append(markup)
     return lilypond_file
 
@@ -56,24 +56,26 @@ def _illustrate_pitch_class_set(set_):
     return lilypond_file
 
 
-def _illustrate_pitch_range(pitch_range):
-    start_pitch_clef = _indicators.Clef.from_pitches([pitch_range.start_pitch])
-    stop_pitch_clef = _indicators.Clef.from_pitches([pitch_range.stop_pitch])
-    start_note = _score.Note(pitch_range.start_pitch, 1)
-    stop_note = _score.Note(pitch_range.stop_pitch, 1)
+def _illustrate_pitch_range(range_):
+    start_pitch = _pitch.NamedPitch(range_.start_pitch)
+    stop_pitch = _pitch.NamedPitch(range_.stop_pitch)
+    start_pitch_clef = _indicators.Clef.from_pitches([start_pitch])
+    stop_pitch_clef = _indicators.Clef.from_pitches([stop_pitch])
+    start_note = _score.Note(range_.start_pitch, 1)
+    stop_note = _score.Note(range_.stop_pitch, 1)
     if start_pitch_clef == stop_pitch_clef:
         if start_pitch_clef == _indicators.Clef("bass"):
             bass_staff = _score.Staff(name="Bass_Staff")
             _bind.attach(_indicators.Clef("bass"), bass_staff)
             bass_staff.extend([start_note, stop_note])
-            bass_leaves = _selection.Selection(bass_staff).leaves()
+            bass_leaves = _select.leaves(bass_staff)
             _spanners.glissando(bass_leaves)
             score = _score.Score([bass_staff], name="Score")
         else:
             treble_staff = _score.Staff(name="Treble_Staff")
             _bind.attach(_indicators.Clef("treble"), treble_staff)
             treble_staff.extend([start_note, stop_note])
-            treble_leaves = _selection.Selection(treble_staff).leaves()
+            treble_leaves = _select.leaves(treble_staff)
             _spanners.glissando(treble_leaves)
             score = _score.Score([treble_staff], name="Score")
     else:
@@ -81,7 +83,7 @@ def _illustrate_pitch_range(pitch_range):
         treble_staff, bass_staff = score["Treble_Staff"], score["Bass_Staff"]
         bass_staff.extend([start_note, stop_note])
         treble_staff.extend("s1 s1")
-        bass_leaves = _selection.Selection(bass_staff).leaves()
+        bass_leaves = _select.leaves(bass_staff)
         _spanners.glissando(bass_leaves)
         _bind.attach(_indicators.StaffChange("Treble_Staff"), bass_staff[1])
         _bind.attach(_indicators.Clef("treble"), treble_staff[0])
@@ -154,7 +156,7 @@ def _illustrate_pitch_class_segment(
         markup = figure_name
     if markup is not None:
         direction = markup_direction
-        markup = _new.new(markup, direction=direction)
+        markup = dataclasses.replace(markup, direction=direction)
         _bind.attach(markup, notes[0])
     voice = _score.Voice(notes, name="Voice")
     staff = _score.Staff([voice], name="Staff")
@@ -179,10 +181,12 @@ def _illustrate_pitch_class_segment(
     system-system-spacing.padding = 10
     top-markup-spacing.padding = 4
 }"""
-    _deprecated.add_final_bar_line(score)
+    leaf = _select.leaf(score, -1)
+    bar_line = _indicators.BarLine("|.")
+    _bind.attach(bar_line, leaf)
     string = r"\override Score.BarLine.transparent = ##f"
     command = _overrides.LilyPondLiteral(string, "after")
-    last_leaf = _selection.Selection(score).leaves()[-1]
+    last_leaf = _select.leaf(score, -1)
     _bind.attach(command, last_leaf)
     lilypond_file = _lilypondfile.LilyPondFile([preamble, score])
     return lilypond_file
@@ -199,11 +203,11 @@ _class_to_method = dict(
         (_markups.Markup, _illustrate_markup),
         (_metricmodulation.MetricModulation, _illustrate_metric_modulation),
         (_timespan.OffsetCounter, _illustrate_markup_maker),
-        (_pitch.PitchRange, _illustrate_pitch_range),
-        (_pitch.PitchClassSet, _illustrate_pitch_class_set),
-        (_pitch.PitchSegment, _illustrate_pitch_segment),
-        (_pitch.PitchClassSegment, _illustrate_pitch_class_segment),
-        (_pitch.PitchSet, _illustrate_pitch_set),
+        (_pcollections.PitchRange, _illustrate_pitch_range),
+        (_pcollections.PitchClassSet, _illustrate_pitch_class_set),
+        (_pcollections.PitchSegment, _illustrate_pitch_segment),
+        (_pcollections.PitchClassSegment, _illustrate_pitch_class_segment),
+        (_pcollections.PitchSet, _illustrate_pitch_set),
         (_timespan.Timespan, _illustrate_timespan),
         (_timespan.TimespanList, _illustrate_markup_maker),
     ]
@@ -426,22 +430,22 @@ def make_piano_score(leaves=None, lowest_treble_pitch="B3"):
     return score
 
 
-def selection(selection, time_signatures=None, *, includes=None):
+def selection(components, time_signatures=None, *, includes=None):
     """
-    Wraps ``selection`` in LilyPond file for doc examples.
+    Wraps ``components`` in LilyPond file for doc examples.
     """
     if time_signatures is None:
-        duration = _get.duration(selection)
+        duration = _get.duration(components)
         time_signature = _indicators.TimeSignature(duration)
-        _bind.attach(time_signature, _selection.Selection(selection).leaf(0))
+        _bind.attach(time_signature, _select.leaf(components, 0))
     else:
-        leaves = _selection.Selection(selection).leaves(grace=False)
-        parts = leaves.partition_by_durations(time_signatures)
+        leaves = _select.leaves(components, grace=False)
+        parts = _select.partition_by_durations(leaves, time_signatures)
         assert len(parts) == len(time_signatures)
         for time_signature, part in zip(time_signatures, parts):
             time_signature = _indicators.TimeSignature(time_signature)
-            _bind.attach(time_signature, _selection.Selection(part).leaf(0))
-    staff = _score.Staff(selection, name="Staff")
+            _bind.attach(time_signature, _select.leaf(part, 0))
+    staff = _score.Staff(components, name="Staff")
     score = _score.Score([staff], name="Score")
     items = []
     items.append(r'\include "abjad.ily"')
@@ -492,12 +496,8 @@ def selection_to_score_markup_string(selection):
     _overrides.setting(score).proportionalNotationDuration = False
     indent = 4 * " "
     strings = [r"\score", indent + "{"]
-    strings.extend(
-        [2 * indent + _ for _ in _lilypondformat.lilypond(score).split("\n")]
-    )
-    strings.extend(
-        [2 * indent + _ for _ in _lilypondformat.lilypond(layout_block).split("\n")]
-    )
+    strings.extend([2 * indent + _ for _ in _format.lilypond(score).split("\n")])
+    strings.extend([2 * indent + _ for _ in _format.lilypond(layout_block).split("\n")])
     strings.append(indent + "}")
     string = "\n".join(strings)
     return string
