@@ -500,7 +500,8 @@ def graph(
 
         ..  docs::
 
-            >>> print(format(staff.__graph__(), "graphviz"))
+            >>> graph = abjad.io._graph_container(staff)
+            >>> print(format(graph, "graphviz"))
             digraph G {
                 graph [style=rounded];
                 node [fontname=Arial,
@@ -604,6 +605,8 @@ def graph(
 
     Opens image in default image viewer.
     """
+    if isinstance(graphable, _score.Container):
+        graphable = _graph_container(graphable)
     grapher = AbjadGrapher(graphable, format_=format_, layout=layout, **keywords)
     result = grapher()
     if not result:
@@ -615,34 +618,6 @@ def graph(
         return format_time, render_time
 
 
-def play(illustrable, return_timing=False, **keywords):
-    """
-    Plays ``argument``.
-
-    ..  container:: example
-
-        >>> note = abjad.Note("c'4")
-        >>> abjad.play(note) # doctest: +SKIP
-
-    Makes MIDI file.
-
-    Appends ``.mid`` filename extension under Windows.
-
-    Appends ``.midi`` filename extension under other operating systems.
-
-    Opens MIDI file.
-    """
-    player = Player(illustrable, **keywords)
-    result = player()
-    if not result:
-        return
-    _, format_time, render_time, success, log = result
-    if not success:
-        print(log)
-    if return_timing:
-        return format_time, render_time
-
-
 def show(illustrable, return_timing=False, **keywords):
     r"""
     Shows ``argument``.
@@ -858,7 +833,7 @@ def open_file(
     *,
     application: str = None,
     line_number: int = None,
-    test: bool = None,
+    test: bool = False,
 ):
     """
     Opens ``file_path``.
