@@ -1,12 +1,16 @@
 import typing
 
 from . import _iterate
+from . import duration as _duration
+from . import pcollections as _pcollections
 from . import pitch as _pitch
 from . import score as _score
-from . import selection as _selection
+from . import select as _select
 
 
-def components(argument, prototype=None, *, exclude=None, grace=None, reverse=None):
+def components(
+    argument, prototype=None, *, exclude=None, grace=None, reverse=None
+) -> typing.Generator:
     r"""
     Iterates components in ``argument``.
 
@@ -81,13 +85,13 @@ def components(argument, prototype=None, *, exclude=None, grace=None, reverse=No
 
         >>> for component in abjad.iterate.components(staff):
         ...     component
-        <Staff{1}>
-        <Voice-"Music_Voice"{4}>
+        Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+        Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
         Note("c'4")
         BeforeGraceContainer("cs'16")
         Note("cs'16")
         Note("d'4")
-        <<<2>>>
+        Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
         OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
         Chord("<e' g'>16")
         Note("gs'16")
@@ -101,12 +105,12 @@ def components(argument, prototype=None, *, exclude=None, grace=None, reverse=No
 
         >>> for component in abjad.iterate.components(staff, reverse=True):
         ...     component
-        <Staff{1}>
-        <Voice-"Music_Voice"{4}>
+        Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+        Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
         AfterGraceContainer("fs'16")
         Note("fs'16")
         Note("f'4")
-        <<<2>>>
+        Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
         Voice("e'4", name='Music_Voice')
         Note("e'4")
         OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
@@ -149,27 +153,26 @@ def components(argument, prototype=None, *, exclude=None, grace=None, reverse=No
 
         >>> for component in abjad.iterate.components(staff, grace=False):
         ...     component
-        <Staff{1}>
-        <Voice-"Music_Voice"{4}>
+        Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+        Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
         Note("c'4")
         Note("d'4")
-        <<<2>>>
+        Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
         Voice("e'4", name='Music_Voice')
         Note("e'4")
         Note("f'4")
 
         >>> for component in abjad.iterate.components(staff, grace=False, reverse=True):
         ...     component
-        <Staff{1}>
-        <Voice-"Music_Voice"{4}>
+        Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+        Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
         Note("f'4")
-        <<<2>>>
+        Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
         Voice("e'4", name='Music_Voice')
         Note("e'4")
         Note("d'4")
         Note("c'4")
 
-    Returns generator.
     """
     return _iterate._public_iterate_components(
         argument,
@@ -188,7 +191,7 @@ def leaves(
     grace=None,
     pitched=None,
     reverse=None,
-):
+) -> typing.Generator:
     r"""
     Iterates leaves in ``argument``.
 
@@ -412,7 +415,6 @@ def leaves(
         Rest('r8')
         Rest('r8')
 
-    Returns generator.
     """
     return _iterate._public_iterate_leaves(
         argument,
@@ -466,10 +468,10 @@ def logical_ties(
         >>> for logical_tie in abjad.iterate.logical_ties(staff):
         ...     logical_tie
         ...
-        LogicalTie([Note("c'4"), Note("c'16")])
-        LogicalTie([Note("d'8")])
-        LogicalTie([Note("e'8")])
-        LogicalTie([Note("f'4"), Note("f'16")])
+        LogicalTie(items=[Note("c'4"), Note("c'16")])
+        LogicalTie(items=[Note("d'8")])
+        LogicalTie(items=[Note("e'8")])
+        LogicalTie(items=[Note("f'4"), Note("f'16")])
 
     ..  container:: example
 
@@ -541,65 +543,65 @@ def logical_ties(
 
         >>> for lt in abjad.iterate.logical_ties(staff):
         ...     lt
-        LogicalTie([Note("c'4")])
-        LogicalTie([Note("cs'16")])
-        LogicalTie([Note("d'4")])
-        LogicalTie([Chord("<e' g'>16")])
-        LogicalTie([Note("gs'16")])
-        LogicalTie([Note("a'16")])
-        LogicalTie([Note("as'16")])
-        LogicalTie([Note("e'4")])
-        LogicalTie([Note("f'4")])
-        LogicalTie([Note("fs'16")])
+        LogicalTie(items=[Note("c'4")])
+        LogicalTie(items=[Note("cs'16")])
+        LogicalTie(items=[Note("d'4")])
+        LogicalTie(items=[Chord("<e' g'>16")])
+        LogicalTie(items=[Note("gs'16")])
+        LogicalTie(items=[Note("a'16")])
+        LogicalTie(items=[Note("as'16")])
+        LogicalTie(items=[Note("e'4")])
+        LogicalTie(items=[Note("f'4")])
+        LogicalTie(items=[Note("fs'16")])
 
         >>> for lt in abjad.iterate.logical_ties(staff, reverse=True):
         ...     lt
-        LogicalTie([Note("fs'16")])
-        LogicalTie([Note("f'4")])
-        LogicalTie([Note("e'4")])
-        LogicalTie([Note("as'16")])
-        LogicalTie([Note("a'16")])
-        LogicalTie([Note("gs'16")])
-        LogicalTie([Chord("<e' g'>16")])
-        LogicalTie([Note("d'4")])
-        LogicalTie([Note("cs'16")])
-        LogicalTie([Note("c'4")])
+        LogicalTie(items=[Note("fs'16")])
+        LogicalTie(items=[Note("f'4")])
+        LogicalTie(items=[Note("e'4")])
+        LogicalTie(items=[Note("as'16")])
+        LogicalTie(items=[Note("a'16")])
+        LogicalTie(items=[Note("gs'16")])
+        LogicalTie(items=[Chord("<e' g'>16")])
+        LogicalTie(items=[Note("d'4")])
+        LogicalTie(items=[Note("cs'16")])
+        LogicalTie(items=[Note("c'4")])
 
         Set ``grace=True`` to iterate grace logical ties only:
 
         >>> for lt in abjad.iterate.logical_ties(staff, grace=True):
         ...     lt
-        LogicalTie([Note("cs'16")])
-        LogicalTie([Chord("<e' g'>16")])
-        LogicalTie([Note("gs'16")])
-        LogicalTie([Note("a'16")])
-        LogicalTie([Note("as'16")])
-        LogicalTie([Note("fs'16")])
+        LogicalTie(items=[Note("cs'16")])
+        LogicalTie(items=[Chord("<e' g'>16")])
+        LogicalTie(items=[Note("gs'16")])
+        LogicalTie(items=[Note("a'16")])
+        LogicalTie(items=[Note("as'16")])
+        LogicalTie(items=[Note("fs'16")])
 
         >>> for lt in abjad.iterate.logical_ties(staff, grace=True, reverse=True):
         ...     lt
-        LogicalTie([Note("fs'16")])
-        LogicalTie([Note("as'16")])
-        LogicalTie([Note("a'16")])
-        LogicalTie([Note("gs'16")])
-        LogicalTie([Chord("<e' g'>16")])
-        LogicalTie([Note("cs'16")])
+        LogicalTie(items=[Note("fs'16")])
+        LogicalTie(items=[Note("as'16")])
+        LogicalTie(items=[Note("a'16")])
+        LogicalTie(items=[Note("gs'16")])
+        LogicalTie(items=[Chord("<e' g'>16")])
+        LogicalTie(items=[Note("cs'16")])
 
         Set ``grace=False`` to iterate nongrace logical ties only:
 
         >>> for lt in abjad.iterate.logical_ties(staff, grace=False):
         ...     lt
-        LogicalTie([Note("c'4")])
-        LogicalTie([Note("d'4")])
-        LogicalTie([Note("e'4")])
-        LogicalTie([Note("f'4")])
+        LogicalTie(items=[Note("c'4")])
+        LogicalTie(items=[Note("d'4")])
+        LogicalTie(items=[Note("e'4")])
+        LogicalTie(items=[Note("f'4")])
 
         >>> for lt in abjad.iterate.logical_ties(staff, grace=False, reverse=True):
         ...     lt
-        LogicalTie([Note("f'4")])
-        LogicalTie([Note("e'4")])
-        LogicalTie([Note("d'4")])
-        LogicalTie([Note("c'4")])
+        LogicalTie(items=[Note("f'4")])
+        LogicalTie(items=[Note("e'4")])
+        LogicalTie(items=[Note("d'4")])
+        LogicalTie(items=[Note("c'4")])
 
     ..  container:: example
 
@@ -638,41 +640,41 @@ def logical_ties(
 
         >>> for lt in abjad.iterate.logical_ties(staff):
         ...     lt
-        LogicalTie([Note("c'4"), Note("c'8")])
-        LogicalTie([Note("d'4")])
-        LogicalTie([Note("e'4"), Note("e'8")])
-        LogicalTie([Note("f'8")])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Note("d'4")])
+        LogicalTie(items=[Note("e'4"), Note("e'8")])
+        LogicalTie(items=[Note("f'8")])
 
         >>> for lt in abjad.iterate.logical_ties(staff, reverse=True):
         ...     lt
-        LogicalTie([Note("f'8")])
-        LogicalTie([Note("e'4"), Note("e'8")])
-        LogicalTie([Note("d'4")])
-        LogicalTie([Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Note("f'8")])
+        LogicalTie(items=[Note("e'4"), Note("e'8")])
+        LogicalTie(items=[Note("d'4")])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
 
         Set ``nontrivial=True`` to iterate nontrivial logical ties only:
 
         >>> for lt in abjad.iterate.logical_ties(staff, nontrivial=True):
         ...     lt
-        LogicalTie([Note("c'4"), Note("c'8")])
-        LogicalTie([Note("e'4"), Note("e'8")])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Note("e'4"), Note("e'8")])
 
         >>> for lt in abjad.iterate.logical_ties(staff, nontrivial=True, reverse=True):
         ...     lt
-        LogicalTie([Note("e'4"), Note("e'8")])
-        LogicalTie([Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Note("e'4"), Note("e'8")])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
 
         Set ``nontrivial=False`` to iterate trivial logical ties only:
 
         >>> for lt in abjad.iterate.logical_ties(staff, nontrivial=False):
         ...     lt
-        LogicalTie([Note("d'4")])
-        LogicalTie([Note("f'8")])
+        LogicalTie(items=[Note("d'4")])
+        LogicalTie(items=[Note("f'8")])
 
         >>> for lt in abjad.iterate.logical_ties(staff, nontrivial=False, reverse=True):
         ...     lt
-        LogicalTie([Note("f'8")])
-        LogicalTie([Note("d'4")])
+        LogicalTie(items=[Note("f'8")])
+        LogicalTie(items=[Note("d'4")])
 
     ..  container:: example
 
@@ -709,41 +711,41 @@ def logical_ties(
 
         >>> for lt in abjad.iterate.logical_ties(staff):
         ...     lt
-        LogicalTie([Note("c'4"), Note("c'8")])
-        LogicalTie([Rest('r4')])
-        LogicalTie([Note("d'4"), Note("d'8")])
-        LogicalTie([Rest('r4')])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Rest('r4')])
+        LogicalTie(items=[Note("d'4"), Note("d'8")])
+        LogicalTie(items=[Rest('r4')])
 
         >>> for lt in abjad.iterate.logical_ties(staff, reverse=True):
         ...     lt
-        LogicalTie([Rest('r4')])
-        LogicalTie([Note("d'4"), Note("d'8")])
-        LogicalTie([Rest('r4')])
-        LogicalTie([Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Rest('r4')])
+        LogicalTie(items=[Note("d'4"), Note("d'8")])
+        LogicalTie(items=[Rest('r4')])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
 
         Set ``pitched=True`` to iterate pitched logical ties only:
 
         >>> for lt in abjad.iterate.logical_ties(staff, pitched=True):
         ...     lt
-        LogicalTie([Note("c'4"), Note("c'8")])
-        LogicalTie([Note("d'4"), Note("d'8")])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Note("d'4"), Note("d'8")])
 
         >>> for lt in abjad.iterate.logical_ties(staff, pitched=True, reverse=True):
         ...     lt
-        LogicalTie([Note("d'4"), Note("d'8")])
-        LogicalTie([Note("c'4"), Note("c'8")])
+        LogicalTie(items=[Note("d'4"), Note("d'8")])
+        LogicalTie(items=[Note("c'4"), Note("c'8")])
 
         Set ``pitched=False`` to iterate unpitched logical ties only:
 
         >>> for lt in abjad.iterate.logical_ties(staff, pitched=False):
         ...     lt
-        LogicalTie([Rest('r4')])
-        LogicalTie([Rest('r4')])
+        LogicalTie(items=[Rest('r4')])
+        LogicalTie(items=[Rest('r4')])
 
         >>> for lt in abjad.iterate.logical_ties(staff, pitched=False, reverse=True):
         ...     lt
-        LogicalTie([Rest('r4')])
-        LogicalTie([Rest('r4')])
+        LogicalTie(items=[Rest('r4')])
+        LogicalTie(items=[Rest('r4')])
 
     ..  container:: example
 
@@ -773,9 +775,8 @@ def logical_ties(
         >>> for logical_tie in abjad.iterate.logical_ties(selection):
         ...     logical_tie
         ...
-        LogicalTie([Note("c'8"), Note("c'8"), Note("c'8")])
+        LogicalTie(items=[Note("c'8"), Note("c'8"), Note("c'8")])
 
-    Returns generator.
     """
     return _iterate._iterate_logical_ties(
         argument,
@@ -784,11 +785,11 @@ def logical_ties(
         nontrivial=nontrivial,
         pitched=pitched,
         reverse=reverse,
-        wrapper_class=_selection.LogicalTie,
+        wrapper_class=_select.LogicalTie,
     )
 
 
-def pitches(argument):
+def pitches(argument) -> typing.Generator:
     r"""
     Iterates pitches in ``argument``.
 
@@ -855,7 +856,6 @@ def pitches(argument):
         NamedPitch("e'")
         NamedPitch("fs'")
 
-    Returns generator.
     """
     if isinstance(argument, _pitch.Pitch):
         pitch = _pitch.NamedPitch(argument)
@@ -867,7 +867,7 @@ def pitches(argument):
         pass
     if isinstance(argument, _score.Chord):
         result.extend(argument.written_pitches)
-    elif isinstance(argument, _pitch.PitchSet):
+    elif isinstance(argument, _pcollections.PitchSet):
         result.extend(sorted(list(argument)))
     elif isinstance(argument, (list, tuple, set)):
         for item in argument:
@@ -887,7 +887,9 @@ def pitches(argument):
         yield pitch
 
 
-def timeline(argument, prototype=None, *, exclude=None, reverse=None):
+def timeline(
+    argument, prototype=None, *, exclude=None, reverse=None
+) -> tuple[_score.Component, ...]:
     r"""
     Iterates leaves in ``argument`` in timeline order.
 
@@ -1040,10 +1042,10 @@ def timeline(argument, prototype=None, *, exclude=None, reverse=None):
 
     Iterates leaves when ``prototype`` is none.
     """
-    components = leaves(argument, prototype=prototype, exclude=exclude)
-    components = list(components)
+    generator = leaves(argument, prototype=prototype, exclude=exclude)
+    components = list(generator)
     components.sort(key=lambda _: _._get_timespan().start_offset)
-    offset_to_components = dict()
+    offset_to_components: dict[_duration.Offset, list[_score.Component]] = dict()
     for component in components:
         start_offset = component._get_timespan().start_offset
         if start_offset not in offset_to_components:
@@ -1051,9 +1053,9 @@ def timeline(argument, prototype=None, *, exclude=None, reverse=None):
     for component in components:
         start_offset = component._get_timespan().start_offset
         offset_to_components[start_offset].append(component)
-    components = []
+    result: list[_score.Component] = []
     for start_offset, list_ in offset_to_components.items():
-        components.extend(list_)
+        result.extend(list_)
     if reverse:
-        components.reverse()
-    return tuple(components)
+        result.reverse()
+    return tuple(result)
