@@ -4,15 +4,15 @@ from . import _inspect
 from . import get as _get
 from . import indicators as _indicators
 from . import instruments as _instruments
-from . import iterate as iterate_
+from . import iterate as _iterate
+from . import pcollections as _pcollections
 from . import pitch as _pitch
 from . import score as _score
-from . import selection as _selection
 
 
-def iterate_out_of_range(components) -> typing.Generator:
+def iterate_out_of_range(argument) -> typing.Generator:
     r"""
-    Iterates out-of-range notes and chords.
+    Iterates out-of-range notes and chords in ``argument``.
 
     ..  container:: example
 
@@ -39,9 +39,7 @@ def iterate_out_of_range(components) -> typing.Generator:
         Chord('<d fs>8')
 
     """
-    leaves = _selection.Selection(components).leaves(pitched=True)
-    assert isinstance(leaves, _selection.Selection), repr(leaves)
-    for leaf in leaves:
+    for leaf in _iterate.leaves(argument, pitched=True):
         instrument = _inspect._get_effective(leaf, _instruments.Instrument)
         if instrument is None:
             raise ValueError("no instrument found.")
@@ -49,9 +47,9 @@ def iterate_out_of_range(components) -> typing.Generator:
             yield leaf
 
 
-def respell_with_flats(selection) -> None:
+def respell_with_flats(argument) -> None:
     r"""
-    Respells pitches in ``selection`` with flats.
+    Respells pitches in ``argument`` with flats.
 
     ..  container:: example
 
@@ -92,19 +90,19 @@ def respell_with_flats(selection) -> None:
             }
 
     """
-    for leaf in iterate_.leaves(selection):
+    for leaf in _iterate.leaves(argument):
         if isinstance(leaf, _score.Note):
             assert leaf.written_pitch is not None
-            leaf.written_pitch = leaf.written_pitch._respell(accidental="flats")
+            leaf.written_pitch = leaf.written_pitch.respell(accidental="flats")
         elif isinstance(leaf, _score.Chord):
             for note_head in leaf.note_heads:
-                pitch = note_head.written_pitch._respell(accidental="flats")
+                pitch = note_head.written_pitch.respell(accidental="flats")
                 note_head.written_pitch = pitch
 
 
-def respell_with_sharps(selection) -> None:
+def respell_with_sharps(argument) -> None:
     r"""
-    Respells pitches in ``selection`` with sharps.
+    Respells pitches in ``argument`` with sharps.
 
     ..  container:: example
 
@@ -145,13 +143,13 @@ def respell_with_sharps(selection) -> None:
             }
 
     """
-    for leaf in iterate_.leaves(selection):
+    for leaf in _iterate.leaves(argument):
         if isinstance(leaf, _score.Note):
             assert leaf.written_pitch is not None
-            leaf.written_pitch = leaf.written_pitch._respell(accidental="sharps")
+            leaf.written_pitch = leaf.written_pitch.respell(accidental="sharps")
         elif isinstance(leaf, _score.Chord):
             for note_head in leaf.note_heads:
-                pitch = note_head.written_pitch._respell(accidental="sharps")
+                pitch = note_head.written_pitch.respell(accidental="sharps")
                 note_head.written_pitch = pitch
 
 
@@ -159,24 +157,24 @@ def sounding_pitches_are_in_range(argument, pitch_range) -> bool:
     """
     Returns true when all pitches in ``argument`` sound within ``pitch_range``.
     """
-    assert isinstance(pitch_range, _pitch.PitchRange), repr(pitch_range)
+    assert isinstance(pitch_range, _pcollections.PitchRange), repr(pitch_range)
     if isinstance(argument, (int, float)):
         pitch = _pitch.NamedPitch(argument)
-        return pitch_range._contains_pitch(pitch)
+        return pitch in pitch_range
     if isinstance(argument, _pitch.Pitch):
-        return pitch_range._contains_pitch(argument)
+        return argument in pitch_range
     if hasattr(argument, "written_pitch"):
         sounding_pitch = _inspect._get_sounding_pitch(argument)
-        return pitch_range._contains_pitch(sounding_pitch)
+        return sounding_pitch in pitch_range
     if hasattr(argument, "written_pitches"):
         sounding_pitches = _inspect._get_sounding_pitches(argument)
-        return all(pitch_range._contains_pitch(_) for _ in sounding_pitches)
-    pitches = list(iterate_.pitches(argument))
+        return all(_ in pitch_range for _ in sounding_pitches)
+    pitches = list(_iterate.pitches(argument))
     if pitches:
-        return all(pitch_range._contains_pitch(_) for _ in pitches)
+        return all(_ in pitch_range for _ in pitches)
     else:
         try:
-            return all(pitch_range._contains_pitch(_) for _ in argument)
+            return all(_ in pitch_range for _ in argument)
         except TypeError:
             return False
     return False
@@ -221,7 +219,7 @@ def transpose_from_sounding_pitch(argument) -> None:
             }
 
     """
-    for leaf in iterate_.leaves(argument, pitched=True):
+    for leaf in _iterate.leaves(argument, pitched=True):
         instrument = _inspect._get_effective(leaf, _instruments.Instrument)
         if not instrument:
             continue
@@ -281,7 +279,7 @@ def transpose_from_written_pitch(argument) -> None:
             }
 
     """
-    for leaf in iterate_.leaves(argument, pitched=True):
+    for leaf in _iterate.leaves(argument, pitched=True):
         instrument = _inspect._get_effective(leaf, _instruments.Instrument)
         if not instrument:
             continue
