@@ -10,7 +10,6 @@ from . import math as _math
 from . import pitch as _pitch
 from . import ratio as _ratio
 from . import score as _score
-from . import selection as _selection
 from . import sequence as _sequence
 from . import spanners as _spanners
 from . import tag as _tag
@@ -374,7 +373,7 @@ class LeafMaker:
         >>> durations = [abjad.Duration(3, 8), abjad.Duration(5, 8)]
         >>> leaves = maker(pitches, durations)
         >>> leaves
-        Selection([MultimeasureRest('R1 * 3/8'), MultimeasureRest('R1 * 5/8')])
+        [MultimeasureRest('R1 * 3/8'), MultimeasureRest('R1 * 5/8')]
 
         >>> abjad.attach(abjad.TimeSignature((3, 8)), leaves[0])
         >>> abjad.attach(abjad.TimeSignature((5, 8)), leaves[1])
@@ -423,7 +422,7 @@ class LeafMaker:
         >>> pitches = [None]
         >>> durations = [abjad.Duration(13, 16)]
         >>> maker(pitches, durations)
-        Selection([Skip('s2.'), Skip('s16')])
+        [Skip('s2.'), Skip('s16')]
 
     """
 
@@ -445,12 +444,12 @@ class LeafMaker:
     def __init__(
         self,
         *,
-        increase_monotonic: bool = None,
+        increase_monotonic: bool = False,
         forbidden_note_duration: _typings.DurationTyping = None,
         forbidden_rest_duration: _typings.DurationTyping = None,
-        skips_instead_of_rests: bool = None,
+        skips_instead_of_rests: bool = False,
         tag: _tag.Tag = None,
-        use_multimeasure_rests: bool = None,
+        use_multimeasure_rests: bool = False,
     ) -> None:
         if increase_monotonic is not None:
             increase_monotonic = bool(increase_monotonic)
@@ -477,7 +476,7 @@ class LeafMaker:
 
     ### SPECIAL METHODS ###
 
-    def __call__(self, pitches, durations) -> _selection.Selection:
+    def __call__(self, pitches, durations) -> list[_score.Leaf | _score.Tuplet]:
         """
         Calls leaf-maker on ``pitches`` and ``durations``.
         """
@@ -487,12 +486,10 @@ class LeafMaker:
             pitches = [pitches]
         if isinstance(durations, (numbers.Number, tuple)):
             durations = [durations]
-        nonreduced_fractions = _sequence.Sequence(
-            [_duration.NonreducedFraction(_) for _ in durations]
-        )
+        nonreduced_fractions = [_duration.NonreducedFraction(_) for _ in durations]
         size = max(len(nonreduced_fractions), len(pitches))
-        nonreduced_fractions = nonreduced_fractions.repeat_to_length(size)
-        pitches = _sequence.Sequence(pitches).repeat_to_length(size)
+        nonreduced_fractions = _sequence.repeat_to_length(nonreduced_fractions, size)
+        pitches = _sequence.repeat_to_length(pitches, size)
         duration_groups = _duration.Duration._group_by_implied_prolation(
             nonreduced_fractions
         )
@@ -541,7 +538,7 @@ class LeafMaker:
                     tuplet_leaves.extend(leaves)
                 tuplet = _score.Tuplet(multiplier, tuplet_leaves)
                 result.append(tuplet)
-        return _selection.Selection(result)
+        return result
 
     ### PRIVATE METHODS ###
 
@@ -665,7 +662,6 @@ class LeafMaker:
             else:
                 arguments = (written_duration,)
             result.append(class_(*arguments, multiplier=multiplier, tag=tag))
-        result = _selection.Selection(result)
         # tie if required
         if tie_parts and 1 < len(result):
             if not issubclass(class_, (_score.Rest, _score.Skip)):
@@ -914,18 +910,16 @@ class NoteMaker:
     ### INITIALIZER ###
 
     def __init__(
-        self, *, increase_monotonic: bool = None, tag: _tag.Tag = None
+        self, *, increase_monotonic: bool = False, tag: _tag.Tag = None
     ) -> None:
-        if increase_monotonic is not None:
-            increase_monotonic = bool(increase_monotonic)
-        self._increase_monotonic = increase_monotonic
+        self._increase_monotonic = bool(increase_monotonic)
         if tag is not None:
             assert isinstance(tag, _tag.Tag), repr(tag)
         self._tag = tag
 
     ### SPECIAL METHODS ###
 
-    def __call__(self, pitches, durations) -> _selection.Selection:
+    def __call__(self, pitches, durations) -> list[_score.Note | _score.Tuplet]:
         """
         Calls note-maker on ``pitches`` and ``durations``.
         """
@@ -935,12 +929,10 @@ class NoteMaker:
             pitches = [pitches]
         if isinstance(durations, (numbers.Number, tuple)):
             durations = [durations]
-        nonreduced_fractions = _sequence.Sequence(
-            [_duration.NonreducedFraction(_) for _ in durations]
-        )
+        nonreduced_fractions = [_duration.NonreducedFraction(_) for _ in durations]
         size = max(len(nonreduced_fractions), len(pitches))
-        nonreduced_fractions = nonreduced_fractions.repeat_to_length(size)
-        pitches = _sequence.Sequence(pitches).repeat_to_length(size)
+        nonreduced_fractions = _sequence.repeat_to_length(nonreduced_fractions, size)
+        pitches = _sequence.repeat_to_length(pitches, size)
         durations = _duration.Duration._group_by_implied_prolation(nonreduced_fractions)
         result: typing.List[typing.Union[_score.Note, _score.Tuplet]] = []
         for duration in durations:
@@ -974,7 +966,7 @@ class NoteMaker:
                 )
                 tuplet = _score.Tuplet(multiplier, ns)
                 result.append(tuplet)
-        return _selection.Selection(result)
+        return result
 
     ### PRIVATE METHODS ###
 
@@ -1034,7 +1026,7 @@ class NoteMaker:
 
 
 def tuplet_from_duration_and_ratio(
-    duration, ratio, *, increase_monotonic: bool = None, tag: _tag.Tag = None
+    duration, ratio, *, increase_monotonic: bool = False, tag: _tag.Tag = None
 ) -> _score.Tuplet:
     r"""
     Makes tuplet from ``duration`` and ``ratio``.
@@ -1329,6 +1321,7 @@ def tuplet_from_duration_and_ratio(
     basic_written_duration = basic_prolated_duration.equal_or_greater_assignable
     written_durations = [x * basic_written_duration for x in ratio.numbers]
     leaf_maker = LeafMaker(increase_monotonic=increase_monotonic, tag=tag)
+    notes: list[_score.Leaf | _score.Tuplet]
     try:
         notes = [
             _score.Note(0, x, tag=tag) if 0 < x else _score.Rest(abs(x), tag=tag)
@@ -1339,7 +1332,7 @@ def tuplet_from_duration_and_ratio(
         note_durations = [_duration.Duration(x, denominator) for x in ratio.numbers]
         pitches = [None if note_duration < 0 else 0 for note_duration in note_durations]
         leaf_durations = [abs(note_duration) for note_duration in note_durations]
-        notes = list(leaf_maker(pitches, leaf_durations))
+        notes = leaf_maker(pitches, leaf_durations)
     tuplet = _score.Tuplet.from_duration(duration, notes, tag=tag)
     tuplet.normalize_multiplier()
     return tuplet
@@ -1674,6 +1667,7 @@ def tuplet_from_leaf_and_ratio(
     basic_written_duration = basic_prolated_duration.equal_or_greater_assignable
     written_durations = [_ * basic_written_duration for _ in proportions.numbers]
     maker = NoteMaker()
+    notes: list[_score.Leaf | _score.Tuplet]
     try:
         notes = [_score.Note(0, x) for x in written_durations]
     except _exceptions.AssignabilityError:
@@ -1908,7 +1902,7 @@ def tuplet_from_ratio_and_pair(
             math.log(_math.weight(ratio.numbers), 2) - math.log(numerator, 2)
         )
         denominator = int(denominator * 2**exponent)
-        components: typing.List[typing.Union[_score.Note, _score.Rest]] = []
+        components: list[_score.Leaf | _score.Tuplet] = []
         for x in ratio.numbers:
             if not x:
                 raise ValueError("no divide zero values.")
