@@ -1,15 +1,13 @@
+import dataclasses
 import typing
 
 from . import _inspect
 from . import bundle as _bundle
 from . import enums as _enums
-from . import format as _format
 from . import illustrators as _illustrators
 from . import markups as _markups
-from . import new as _new
 from . import ratio as _ratio
 from . import score as _score
-from . import selection as _selection
 from . import typings as _typings
 
 
@@ -17,7 +15,6 @@ class MetricModulation:
     r"""
     Metric modulation.
 
-
     ..  container:: example
 
         With notes:
@@ -25,7 +22,7 @@ class MetricModulation:
         >>> metric_modulation = abjad.MetricModulation(
         ...     left_rhythm=abjad.Note("c'8."),
         ...     right_rhythm=abjad.Note("c'4."),
-        ...     )
+        ... )
 
         >>> lilypond_file = abjad.LilyPondFile(
         ...     [r'\include "abjad.ily"', metric_modulation]
@@ -45,7 +42,7 @@ class MetricModulation:
         >>> metric_modulation = abjad.MetricModulation(
         ...     left_rhythm=abjad.Tuplet((4, 5), "c'4"),
         ...     right_rhythm=abjad.Note("c'4"),
-        ...     )
+        ... )
 
         >>> lilypond_file = abjad.LilyPondFile(
         ...     [r'\include "abjad.ily"', metric_modulation]
@@ -355,14 +352,12 @@ class MetricModulation:
         left_rhythm,
         right_rhythm,
         *,
-        hide: bool = None,
+        hide: bool = False,
         left_markup: _markups.Markup = None,
         right_markup: _markups.Markup = None,
         scale: typing.Tuple[_typings.Number, _typings.Number] = (1, 1),
     ) -> None:
-        if hide is not None:
-            hide = bool(hide)
-        self._hide = hide
+        self._hide = bool(hide)
         left_rhythm = self._initialize_rhythm(left_rhythm)
         self._left_rhythm = left_rhythm
         right_rhythm = self._initialize_rhythm(right_rhythm)
@@ -402,11 +397,11 @@ class MetricModulation:
             ...     )
 
             >>> metric_modulation_1.ratio
-            Ratio((2, 3))
+            Ratio(numbers=(2, 3))
             >>> metric_modulation_2.ratio
-            Ratio((2, 3))
+            Ratio(numbers=(2, 3))
             >>> metric_modulation_3.ratio
-            Ratio((4, 5))
+            Ratio(numbers=(4, 5))
 
             >>> metric_modulation_1 == metric_modulation_1
             True
@@ -444,9 +439,9 @@ class MetricModulation:
 
     def __repr__(self) -> str:
         """
-        Gets interpreter representation.
+        Gets repr.
         """
-        return _format.get_repr(self)
+        return f"{type(self).__name__}(left_rhythm={self.left_rhythm!r}, right_rhythm={self.right_rhythm!r})"
 
     def __str__(self) -> str:
         r"""
@@ -502,7 +497,7 @@ class MetricModulation:
         bundle = _bundle.LilyPondFormatBundle()
         if not self.hide:
             markup = self._get_markup()
-            markup = _new.new(markup, direction=_enums.Up)
+            markup = dataclasses.replace(markup, direction=_enums.Up)
             markup_format_pieces = markup._get_format_pieces()
             bundle.after.markup.extend(markup_format_pieces)
         return bundle
@@ -565,10 +560,9 @@ class MetricModulation:
             raise Exception("implement tied note values.")
 
     def _initialize_rhythm(self, rhythm):
-        if not hasattr(rhythm, "_items"):
-            selection = _selection.Selection([rhythm])
+        if isinstance(rhythm, _score.Component):
+            selection = [rhythm]
         else:
-            assert hasattr(rhythm, "_items"), repr(rhythm)
             selection = rhythm
         return selection
 
@@ -605,7 +599,7 @@ class MetricModulation:
     ### PUBLIC PROPERTIES ###
 
     @property
-    def hide(self) -> typing.Optional[bool]:
+    def hide(self) -> bool:
         """
         Is true when metric modulation generates no LilyPond output.
         """
@@ -639,7 +633,7 @@ class MetricModulation:
             ...     right_rhythm=abjad.Note("c'4."),
             ...     )
             >>> metric_modulation.left_rhythm
-            Selection([Note("c'4")])
+            [Note("c'4")]
 
         Returns selection.
         """
@@ -657,7 +651,7 @@ class MetricModulation:
             ...     right_rhythm=abjad.Note("c'4"),
             ...     )
             >>> metric_modulation.ratio
-            Ratio((2, 3))
+            Ratio(numbers=(2, 3))
 
         """
         left_duration = _inspect._get_duration(self.left_rhythm)
@@ -693,7 +687,7 @@ class MetricModulation:
             ...     right_rhythm=abjad.Note("c'4."),
             ...     )
             >>> metric_modulation.right_rhythm
-            Selection([Note("c'4.")])
+            [Note("c'4.")]
 
         """
         return self._right_rhythm
