@@ -1,6 +1,8 @@
+import collections
 import copy as python_copy
 import itertools
 
+from . import _inspect
 from . import bind as _bind
 from . import duration as _duration
 from . import enums as _enums
@@ -9,41 +11,306 @@ from . import get as _get
 from . import indicators as _indicators
 from . import iterate as iterate_
 from . import makers as _makers
+from . import parentage as _parentage
 from . import pitch as _pitch
 from . import ratio as _ratio
 from . import score as _score
-from . import selection as _selection
+from . import select as _select
 from . import sequence as _sequence
 from . import spanners as _spanners
 
 
-def _extract(COMPONENT):
-    selection = _selection.Selection([COMPONENT])
-    parent, start, stop = selection._get_parent_and_start_stop_indices()
+def _are_contiguous_logical_voice(
+    selection, prototype=None, *, ignore_before_after_grace=None
+) -> bool:
+    r"""
+    Is true when items in selection are contiguous components in the same logical voice.
+
+    ..  container:: example
+
+        >>> staff = abjad.Staff("c'4 d'4 e'4 f'4")
+        >>> abjad.mutate._are_contiguous_logical_voice(staff[:])
+        True
+
+        >>> staves = [staff[0], staff[-1]]
+        >>> abjad.mutate._are_contiguous_logical_voice(staves)
+        False
+
+    ..  container:: example
+
+        REGRESSION. Before-grace music may be ignored:
+
+        >>> voice = abjad.Voice("c'4 d' e' f'")
+        >>> container = abjad.BeforeGraceContainer("cs'16")
+        >>> abjad.attach(container, voice[1])
+        >>> abjad.show(voice) # doctest: +SKIP
+
+        ..  docs::
+
+            >>> string = abjad.lilypond(voice)
+            >>> print(string)
+            \new Voice
+            {
+                c'4
+                \grace {
+                    cs'16
+                }
+                d'4
+                e'4
+                f'4
+            }
+
+        >>> voice[:]
+        [Note("c'4"), Note("d'4"), Note("e'4"), Note("f'4")]
+
+        >>> abjad.mutate._are_contiguous_logical_voice(voice[:])
+        False
+
+        >>> abjad.mutate._are_contiguous_logical_voice(
+        ...     voice[:],
+        ...     ignore_before_after_grace=True
+        ... )
+        True
+
+        After-grace music may be ignored, too:
+
+        >>> voice = abjad.Voice("c'4 d' e' f'")
+        >>> container = abjad.AfterGraceContainer("cs'16")
+        >>> abjad.attach(container, voice[0])
+        >>> abjad.show(voice) # doctest: +SKIP
+
+        ..  docs::
+
+            >>> string = abjad.lilypond(voice)
+            >>> print(string)
+            \new Voice
+            {
+                \afterGrace
+                c'4
+                {
+                    cs'16
+                }
+                d'4
+                e'4
+                f'4
+            }
+
+        >>> voice[:]
+        [Note("c'4"), Note("d'4"), Note("e'4"), Note("f'4")]
+
+        >>> abjad.mutate._are_contiguous_logical_voice(voice[:])
+        False
+
+        >>> abjad.mutate._are_contiguous_logical_voice(
+        ...     voice[:],
+        ...     ignore_before_after_grace=True
+        ... )
+        True
+
+    """
+    if not isinstance(selection, collections.abc.Sequence):
+        return False
+    prototype = prototype or (_score.Component,)
+    if not isinstance(prototype, tuple):
+        prototype = (prototype,)
+    assert isinstance(prototype, tuple)
+    if len(selection) == 0:
+        return True
+    if all(isinstance(_, prototype) and _._parent is None for _ in selection):
+        return True
+    first = selection[0]
+    if not isinstance(first, prototype):
+        return False
+    first_parentage = _parentage.Parentage(first)
+    first_logical_voice = first_parentage.logical_voice()
+    first_root = first_parentage.root
+    previous = first
+    for current in selection[1:]:
+        current_parentage = _parentage.Parentage(current)
+        current_logical_voice = current_parentage.logical_voice()
+        # false if wrong type of component found
+        if not isinstance(current, prototype):
+            return False
+        # false if in different logical voices
+        if current_logical_voice != first_logical_voice:
+            return False
+        # false if components are in same score and are discontiguous
+        if current_parentage.root == first_root:
+            if not _immediately_precedes(
+                previous,
+                current,
+                ignore_before_after_grace=ignore_before_after_grace,
+            ):
+                return False
+        previous = current
+    return True
+
+
+def _are_contiguous_same_parent(
+    self, prototype=None, *, ignore_before_after_grace=None
+) -> bool:
+    r"""
+    Is true when items in selection are all contiguous components in the same parent.
+
+    ..  container:: example
+
+        >>> staff = abjad.Staff("c'4 d'4 e'4 f'4")
+        >>> abjad.mutate._are_contiguous_same_parent(staff[:])
+        True
+
+        >>> staves = [staff[0], staff[-1]]
+        >>> abjad.mutate._are_contiguous_same_parent(staves)
+        False
+
+    ..  container:: example
+
+        REGRESSION. Before-grace music music may be ignored:
+
+        >>> voice = abjad.Voice("c'4 d' e' f'")
+        >>> container = abjad.BeforeGraceContainer("cs'16")
+        >>> abjad.attach(container, voice[1])
+        >>> abjad.show(voice) # doctest: +SKIP
+
+        ..  docs::
+
+            >>> string = abjad.lilypond(voice)
+            >>> print(string)
+            \new Voice
+            {
+                c'4
+                \grace {
+                    cs'16
+                }
+                d'4
+                e'4
+                f'4
+            }
+
+        >>> voice[:]
+        [Note("c'4"), Note("d'4"), Note("e'4"), Note("f'4")]
+
+        >>> abjad.mutate._are_contiguous_same_parent(voice[:])
+        False
+
+        >>> abjad.mutate._are_contiguous_same_parent(
+        ...     voice[:],
+        ...     ignore_before_after_grace=True
+        ... )
+        True
+
+        After-grace music may be ignored, too:
+
+        >>> voice = abjad.Voice("c'4 d' e' f'")
+        >>> container = abjad.AfterGraceContainer("cs'16")
+        >>> abjad.attach(container, voice[0])
+        >>> abjad.show(voice) # doctest: +SKIP
+
+        ..  docs::
+
+            >>> string = abjad.lilypond(voice)
+            >>> print(string)
+            \new Voice
+            {
+                \afterGrace
+                c'4
+                {
+                    cs'16
+                }
+                d'4
+                e'4
+                f'4
+            }
+
+        >>> voice[:]
+        [Note("c'4"), Note("d'4"), Note("e'4"), Note("f'4")]
+
+        >>> abjad.mutate._are_contiguous_same_parent(voice[:])
+        False
+
+        >>> abjad.mutate._are_contiguous_same_parent(
+        ...     voice[:],
+        ...     ignore_before_after_grace=True
+        ... )
+        True
+
+    """
+    prototype = prototype or (_score.Component,)
+    if not isinstance(prototype, tuple):
+        prototype = (prototype,)
+    assert isinstance(prototype, tuple)
+    if len(self) == 0:
+        return True
+    if all(isinstance(_, prototype) and _._parent is None for _ in self):
+        return True
+    first = self[0]
+    if not isinstance(first, prototype):
+        return False
+    first_parent = first._parent
+    same_parent = True
+    strictly_contiguous = True
+    previous = first
+    for current in self[1:]:
+        if not isinstance(current, prototype):
+            return False
+        if current._parent is not first_parent:
+            same_parent = False
+        if not _immediately_precedes(
+            previous,
+            current,
+            ignore_before_after_grace=ignore_before_after_grace,
+        ):
+            strictly_contiguous = False
+        if current._parent is not None and (not same_parent or not strictly_contiguous):
+            return False
+        previous = current
+    return True
+
+
+def _attach_tie_to_leaves(selection):
+    for leaf in selection[:-1]:
+        _bind.detach(_indicators.Tie, leaf)
+        _bind.attach(_indicators.Tie(), leaf)
+
+
+def _copy_selection(selection):
+    assert _are_contiguous_logical_voice(selection)
+    new_components = []
+    for component in selection:
+        if isinstance(component, _score.Container):
+            new_component = component._copy_with_children()
+        else:
+            new_component = component.__copy__()
+        new_components.append(new_component)
+    new_components = type(selection)(new_components)
+    return new_components
+
+
+def _extract(component):
+    selection = [component]
+    parent, start, stop = _get_parent_and_start_stop_indices(selection)
     if parent is not None:
-        components = list(getattr(COMPONENT, "components", ()))
+        components = list(getattr(component, "components", ()))
         parent.__setitem__(slice(start, stop + 1), components)
-    return COMPONENT
+    return component
 
 
-def _fuse(SELECTION):
-    assert SELECTION.are_contiguous_logical_voice()
-    if SELECTION.are_leaves():
-        return _fuse_leaves(SELECTION)
-    elif all(isinstance(_, _score.Tuplet) for _ in SELECTION):
-        return _fuse_tuplets(SELECTION)
+def _fuse(components):
+    assert _are_contiguous_logical_voice(components)
+    if all(isinstance(_, _score.Leaf) for _ in components):
+        return _fuse_leaves(components)
+    elif all(isinstance(_, _score.Tuplet) for _ in components):
+        return _fuse_tuplets(components)
     else:
-        raise Exception(f"can only fuse leaves and tuplets (not {SELECTION}).")
+        raise Exception(f"can only fuse leaves and tuplets (not {components}).")
 
 
-def _fuse_leaves(SELECTION):
-    assert SELECTION.are_leaves()
-    assert SELECTION.are_contiguous_logical_voice()
-    leaves = SELECTION
+def _fuse_leaves(leaves):
+    assert all(isinstance(_, _score.Leaf) for _ in leaves)
+    assert _are_contiguous_logical_voice(leaves)
     if len(leaves) <= 1:
         return leaves
-    originally_tied = SELECTION[-1]._has_indicator(_indicators.Tie)
-    total_preprolated = leaves._get_preprolated_duration()
+    originally_tied = leaves[-1]._has_indicator(_indicators.Tie)
+    total_preprolated = sum(_._get_preprolated_duration() for _ in leaves)
     for leaf in leaves[1:]:
         parent = leaf._parent
         if parent:
@@ -51,50 +318,109 @@ def _fuse_leaves(SELECTION):
             del parent[index]
     result = _set_leaf_duration(leaves[0], total_preprolated)
     if not originally_tied:
-        last_leaf = _selection.Selection(result).leaf(-1)
+        last_leaf = _select.leaf(result, -1)
         _bind.detach(_indicators.Tie, last_leaf)
     return result
 
 
-def _fuse_leaves_by_immediate_parent(SELECTION):
+def _fuse_leaves_by_immediate_parent(leaves):
     result = []
-    parts = _get_leaves_grouped_by_immediate_parents(SELECTION)
+    parts = _get_leaves_grouped_by_immediate_parents(leaves)
     for part in parts:
         fused = _fuse(part)
         result.append(fused)
     return result
 
 
-def _fuse_tuplets(SELECTION):
-    assert SELECTION.are_contiguous_same_parent(prototype=_score.Tuplet)
-    if len(SELECTION) == 0:
+def _fuse_tuplets(tuplets):
+    assert _are_contiguous_same_parent(tuplets, prototype=_score.Tuplet)
+    if len(tuplets) == 0:
         return None
-    first = SELECTION[0]
+    first = tuplets[0]
     first_multiplier = first.multiplier
-    for tuplet in SELECTION[1:]:
+    for tuplet in tuplets[1:]:
         if tuplet.multiplier != first_multiplier:
             raise ValueError("tuplets must carry same multiplier.")
     assert isinstance(first, _score.Tuplet)
     new_tuplet = _score.Tuplet(first_multiplier, [])
     wrapped = False
-    if _get.parentage(SELECTION[0]).root is not _get.parentage(SELECTION[-1]).root:
-        dummy_container = _score.Container(SELECTION)
+    if _get.parentage(tuplets[0]).root is not _get.parentage(tuplets[-1]).root:
+        dummy_container = _score.Container(tuplets)
         wrapped = True
-    swap(SELECTION, new_tuplet)
+    swap(tuplets, new_tuplet)
     if wrapped:
         del dummy_container[:]
     return new_tuplet
 
 
-def _get_leaves_grouped_by_immediate_parents(SELECTION):
+def _get_leaves_grouped_by_immediate_parents(leaves):
     result = []
-    pairs_generator = itertools.groupby(SELECTION, lambda x: id(x._parent))
+    pairs_generator = itertools.groupby(leaves, lambda _: id(_._parent))
     for key, values_generator in pairs_generator:
-        group = _selection.Selection(list(values_generator))
+        group = list(values_generator)
         result.append(group)
     return result
 
 
+def _give_components_to_empty_container(selection, container):
+    assert _are_contiguous_same_parent(selection)
+    assert isinstance(container, _score.Container)
+    assert not container
+    components = []
+    for component in selection:
+        components.extend(getattr(component, "components", ()))
+    container._components.extend(components)
+    _set_parents(container)
+
+
+def _get_parent_and_start_stop_indices(selection, ignore_before_after_grace=None):
+    assert _are_contiguous_same_parent(
+        selection, ignore_before_after_grace=ignore_before_after_grace
+    )
+    if selection:
+        first, last = selection[0], selection[-1]
+        parent = first._parent
+        if parent is not None:
+            first_index = parent.index(first)
+            last_index = parent.index(last)
+            return parent, first_index, last_index
+    return None, None, None
+
+
+def _give_position_in_parent_to_container(selection, container):
+    assert _are_contiguous_same_parent(selection)
+    assert isinstance(container, _score.Container)
+    parent, start, stop = _get_parent_and_start_stop_indices(selection)
+    if parent is not None:
+        parent._components.__setitem__(slice(start, start), [container])
+        container._set_parent(parent)
+        for component in selection:
+            component._set_parent(None)
+
+
+def _immediately_precedes(component_1, component_2, ignore_before_after_grace=None):
+    successors = []
+    current = component_1
+    # do not include OnBeatGraceContainer here because
+    # OnBeatGraceContainer is a proper container
+    grace_prototype = (_score.AfterGraceContainer, _score.BeforeGraceContainer)
+    while current is not None:
+        sibling = _inspect._get_sibling_with_graces(current, 1)
+        while (
+            ignore_before_after_grace
+            and sibling is not None
+            and isinstance(sibling._parent, grace_prototype)
+        ):
+            sibling = _inspect._get_sibling_with_graces(sibling, 1)
+        if sibling is None:
+            current = current._parent
+        else:
+            descendants = sibling._get_descendants_starting_with()
+            successors = descendants
+            break
+    return component_2 in successors
+
+
 def _move_indicators(donor_component, recipient_component):
     for wrapper in _get.wrappers(donor_component):
         _bind.detach(wrapper, donor_component)
@@ -106,15 +432,15 @@ def _set_leaf_duration(leaf, new_duration):
     if leaf.multiplier is not None:
         multiplier = new_duration.__div__(leaf.written_duration)
         leaf.multiplier = multiplier
-        return _selection.Selection(leaf)
+        return [leaf]
     try:
         leaf.written_duration = new_duration
-        return _selection.Selection(leaf)
+        return [leaf]
     except _exceptions.AssignabilityError:
         pass
     maker = _makers.NoteMaker()
     components = maker(0, new_duration)
-    new_leaves = _selection.Selection(components).leaves()
+    new_leaves = _select.leaves(components)
     following_leaf_count = len(new_leaves) - 1
     following_leaves = []
     for i in range(following_leaf_count):
@@ -143,7 +469,7 @@ def _set_leaf_duration(leaf, new_duration):
     for all_leaf, new_leaf in zip(all_leaves, new_leaves):
         all_leaf.written_duration = new_leaf.written_duration
     logical_tie = _get.logical_tie(leaf)
-    logical_tie_leaves = list(logical_tie.leaves)
+    logical_tie_leaves = list(logical_tie)
     for leaf_ in logical_tie:
         _bind.detach(_indicators.Tie, leaf_)
         _bind.detach(_indicators.RepeatTie, leaf_)
@@ -157,17 +483,22 @@ def _set_leaf_duration(leaf, new_duration):
     if 1 < len(logical_tie_leaves) and isinstance(leaf, (_score.Note, _score.Chord)):
         _spanners.tie(logical_tie_leaves)
     if isinstance(components[0], _score.Leaf):
-        return _selection.Selection(all_leaves)
+        assert isinstance(all_leaves, list)
+        return all_leaves
     else:
         assert isinstance(components[0], _score.Tuplet)
         assert len(components) == 1
         tuplet = components[0]
         multiplier = tuplet.multiplier
         tuplet = _score.Tuplet(multiplier, [])
-        if not isinstance(all_leaves, _selection.Selection):
-            all_leaves = _selection.Selection(all_leaves)
+        assert isinstance(all_leaves, list)
         wrap(all_leaves, tuplet)
-        return _selection.Selection(tuplet)
+        return [tuplet]
+
+
+def _set_parents(container):
+    for component in container:
+        component._set_parent(container)
 
 
 def _split_container_at_index(CONTAINER, i):
@@ -202,8 +533,8 @@ def _split_container_at_index(CONTAINER, i):
     halves = (left, right)
     nonempty_halves = [half for half in halves if len(half)]
     # incorporate left and right parents in score if possible
-    selection = _selection.Selection(CONTAINER)
-    parent, start, stop = selection._get_parent_and_start_stop_indices()
+    selection = [CONTAINER]
+    parent, start, stop = _get_parent_and_start_stop_indices(selection)
     if parent is not None:
         parent._components.__setitem__(slice(start, stop + 1), nonempty_halves)
         for part in nonempty_halves:
@@ -306,8 +637,7 @@ def _split_container_by_duration(CONTAINER, duration):
                     leaf_left_of_split,
                     leaf_right_of_split,
                 )
-                selection = _selection.Selection(leaves_around_split)
-                selection._attach_tie_to_leaves()
+                _attach_tie_to_leaves(leaves_around_split)
     # return list-wrapped halves of container
     return [left], [right]
 
@@ -320,65 +650,59 @@ def _split_simultaneous_by_duration(CONTAINER, duration):
         left_components_, right_components_ = halves
         left_components.extend(left_components_)
         right_components.extend(right_components_)
-    left_components = _selection.Selection(left_components)
-    right_components = _selection.Selection(right_components)
     left_container = CONTAINER.__copy__()
     right_container = CONTAINER.__copy__()
     left_container.extend(left_components)
     right_container.extend(right_components)
     if _get.parentage(CONTAINER).parent is not None:
-        containers = _selection.Selection([left_container, right_container])
+        containers = [left_container, right_container]
         replace(CONTAINER, containers)
     # return list-wrapped halves of container
     return [left_container], [right_container]
 
 
-def _split_leaf_by_durations(LEAF, durations, cyclic=False):
+def _split_leaf_by_durations(leaf, durations, cyclic=False):
     durations = [_duration.Duration(_) for _ in durations]
-    durations = _sequence.Sequence(durations)
-    leaf_duration = _get.duration(LEAF)
+    leaf_duration = _get.duration(leaf)
     if cyclic:
-        durations = durations.repeat_to_weight(leaf_duration)
+        durations = _sequence.repeat_to_weight(durations, leaf_duration)
     if sum(durations) < leaf_duration:
         last_duration = leaf_duration - sum(durations)
         durations = list(durations)
         durations.append(last_duration)
-        durations = _sequence.Sequence(durations)
-    durations = durations.truncate(weight=leaf_duration)
-    originally_tied = LEAF._has_indicator(_indicators.Tie)
-    originally_repeat_tied = LEAF._has_indicator(_indicators.RepeatTie)
+    durations = _sequence.truncate(durations, weight=leaf_duration)
+    originally_tied = leaf._has_indicator(_indicators.Tie)
+    originally_repeat_tied = leaf._has_indicator(_indicators.RepeatTie)
     result_selections = []
     # detach grace containers
-    before_grace_container = LEAF._before_grace_container
+    before_grace_container = leaf._before_grace_container
     if before_grace_container is not None:
-        _bind.detach(before_grace_container, LEAF)
-    after_grace_container = LEAF._after_grace_container
+        _bind.detach(before_grace_container, leaf)
+    after_grace_container = leaf._after_grace_container
     if after_grace_container is not None:
-        _bind.detach(after_grace_container, LEAF)
+        _bind.detach(after_grace_container, leaf)
     # do other things
-    leaf_prolation = _get.parentage(LEAF).prolation
+    leaf_prolation = _get.parentage(leaf).prolation
     for duration in durations:
-        new_leaf = python_copy.copy(LEAF)
+        new_leaf = python_copy.copy(leaf)
         preprolated_duration = duration / leaf_prolation
         selection = _set_leaf_duration(new_leaf, preprolated_duration)
         result_selections.append(selection)
-    result_components = _sequence.Sequence(result_selections).flatten(depth=-1)
-    result_components = _selection.Selection(result_components)
-    result_leaves = _selection.Selection(result_components).leaves(grace=False)
-    assert all(isinstance(_, _selection.Selection) for _ in result_selections)
+    result_components = _sequence.flatten(result_selections, depth=-1)
+    result_leaves = _select.leaves(result_components, grace=False)
     assert all(isinstance(_, _score.Component) for _ in result_components)
-    assert result_leaves.are_leaves()
+    assert all(isinstance(_, _score.Leaf) for _ in result_leaves)
     # strip result leaves of all indicators
-    for leaf in result_leaves:
-        _bind.detach(object, leaf)
+    for leaf_ in result_leaves:
+        _bind.detach(object, leaf_)
     # replace leaf with flattened result
-    if _get.parentage(LEAF).parent is not None:
-        replace(LEAF, result_components)
+    if _get.parentage(leaf).parent is not None:
+        replace(leaf, result_components)
     # move indicators
     first_result_leaf = result_leaves[0]
     last_result_leaf = result_leaves[-1]
-    for indicator in _get.indicators(LEAF):
-        _bind.detach(indicator, LEAF)
+    for indicator in _get.indicators(leaf):
+        _bind.detach(indicator, leaf)
         direction = getattr(indicator, "_time_orientation", _enums.Left)
         if direction is _enums.Left:
             _bind.attach(indicator, first_result_leaf)
@@ -399,23 +723,20 @@ def _split_leaf_by_durations(LEAF, durations, cyclic=False):
     if isinstance(result_components[0], _score.Tuplet):
         fuse(result_components)
     # tie split notes
-    if isinstance(LEAF, (_score.Note, _score.Chord)) and 1 < len(result_leaves):
-        result_leaves._attach_tie_to_leaves()
+    if isinstance(leaf, (_score.Note, _score.Chord)) and 1 < len(result_leaves):
+        _attach_tie_to_leaves(result_leaves)
     if originally_repeat_tied and not result_leaves[0]._has_indicator(
         _indicators.RepeatTie
     ):
         _bind.attach(_indicators.RepeatTie(), result_leaves[0])
     if originally_tied and not result_leaves[-1]._has_indicator(_indicators.Tie):
         _bind.attach(_indicators.Tie(), result_leaves[-1])
-    assert isinstance(result_leaves, _selection.Selection)
+    assert isinstance(result_leaves, list)
     assert all(isinstance(_, _score.Leaf) for _ in result_leaves)
     return result_leaves
 
 
-### PUBLIC FUNCTIONS ###
-
-
-def copy(argument, n=1):
+def copy(argument, n=1) -> list[_score.Component]:
     r"""
     Copies argument.
 
@@ -513,7 +834,7 @@ def copy(argument, n=1):
             }
 
         >>> selection = staff[2:4]
-        >>> result = selection._copy()
+        >>> result = abjad.mutate.copy(selection)
         >>> new_staff = abjad.Staff(result)
         >>> abjad.show(new_staff) # doctest: +SKIP
 
@@ -530,14 +851,13 @@ def copy(argument, n=1):
         >>> staff[2] is new_staff[0]
         False
 
-    Returns selection of new components.
     """
     if isinstance(argument, _score.Component):
-        selection = _selection.Selection(argument)
+        selection = [argument]
     else:
         selection = argument
     if n == 1:
-        result = selection._copy()
+        result = _copy_selection(selection)
         if isinstance(argument, _score.Component):
             if len(result) == 1:
                 result = result[0]
@@ -578,11 +898,11 @@ def eject_contents(argument):
 
         >>> contents = abjad.mutate.eject_contents(container)
         >>> contents
-        Selection([Note("c'4"), Note("c'4"), Note("d'4"), Note("d'4")])
+        [Note("c'4"), Note("c'4"), Note("d'4"), Note("d'4")]
 
         Container contents can be safely added to a new container:
 
-        >>> staff = abjad.Staff(contents, lilypond_type='RhythmicStaff')
+        >>> staff = abjad.Staff(contents, lilypond_type="RhythmicStaff")
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -627,7 +947,7 @@ def extract(argument):
         >>> staff = abjad.Staff()
         >>> staff.append(abjad.Tuplet((3, 2), "c'4 e'4"))
         >>> staff.append(abjad.Tuplet((3, 2), "d'4 f'4"))
-        >>> leaves = abjad.select(staff).leaves()
+        >>> leaves = abjad.select.leaves(staff)
         >>> time_signature = abjad.TimeSignature((3, 4))
         >>> abjad.attach(time_signature, leaves[0])
         >>> abjad.hairpin('p < f', leaves)
@@ -684,7 +1004,7 @@ def extract(argument):
         >>> staff = abjad.Staff()
         >>> staff.append(abjad.Tuplet((3, 2), "c'4 e'4"))
         >>> staff.append(abjad.Tuplet((3, 2), "d'4 f'4"))
-        >>> leaves = abjad.select(staff).leaves()
+        >>> leaves = abjad.select.leaves(staff)
         >>> abjad.hairpin('p < f', leaves)
         >>> time_signature = abjad.TimeSignature((3, 4))
         >>> abjad.attach(time_signature, leaves[0])
@@ -776,7 +1096,7 @@ def extract(argument):
     return _extract(argument)
 
 
-def fuse(argument):
+def fuse(argument) -> _score.Tuplet | list[_score.Leaf]:
     r"""
     Fuses ``argument``.
 
@@ -788,7 +1108,8 @@ def fuse(argument):
         >>> abjad.show(staff) # doctest: +SKIP
 
         >>> abjad.mutate.fuse(staff[1:])
-        Selection([Note("d'4.")])
+        [Note("d'4.")]
+
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -895,9 +1216,9 @@ def fuse(argument):
                 d'32
             }
 
-        >>> logical_tie = abjad.select(staff[0]).logical_tie()
+        >>> logical_tie = abjad.select.logical_tie(staff[0])
         >>> abjad.mutate.fuse(logical_tie)
-        Selection([Note("d'8..")])
+        [Note("d'8..")]
 
         >>> abjad.show(staff) # doctest: +SKIP
 
@@ -914,17 +1235,14 @@ def fuse(argument):
         >>> abjad.get.has_indicator(staff[0], abjad.Tie)
         False
 
-    Returns selection.
     """
+    _are_contiguous_logical_voice(argument)
     if isinstance(argument, _score.Component):
-        selection = _selection.Selection(argument)
-        return _fuse(selection)
-    elif (
-        isinstance(argument, _selection.Selection)
-        and argument.are_contiguous_logical_voice()
-    ):
-        selection = _selection.Selection(argument)
-        return _fuse(selection)
+        result = _fuse([argument])
+    else:
+        result = _fuse(list(argument))
+    assert isinstance(result, (list, _score.Tuplet)), repr(result)
+    return result
 
 
 def logical_tie_to_tuplet(argument, proportions) -> _score.Tuplet:
@@ -963,7 +1281,7 @@ def logical_tie_to_tuplet(argument, proportions) -> _score.Tuplet:
                 \f
             }
 
-        >>> logical_tie = abjad.select(staff[1]).logical_tie()
+        >>> logical_tie = abjad.select.logical_tie(staff[1])
         >>> abjad.mutate.logical_tie_to_tuplet(logical_tie, [2, 1, 1, 1])
         Tuplet('5:3', "c'8 c'16 c'16 c'16")
 
@@ -1026,18 +1344,20 @@ def logical_tie_to_tuplet(argument, proportions) -> _score.Tuplet:
 
     """
     proportions = _ratio.Ratio(proportions)
-    target_duration = argument._get_preprolated_duration()
+    target_duration = sum(_._get_preprolated_duration() for _ in argument)
+    assert isinstance(target_duration, _duration.Duration)
     prolated_duration = target_duration / sum(proportions.numbers)
     basic_written_duration = prolated_duration.equal_or_greater_power_of_two
     written_durations = [_ * basic_written_duration for _ in proportions.numbers]
-    maker = _makers.NoteMaker()
+    notes: list[_score.Note | _score.Tuplet]
     try:
-        notes = _selection.Selection([_score.Note(0, _) for _ in written_durations])
+        notes = [_score.Note(0, _) for _ in written_durations]
     except _exceptions.AssignabilityError:
         denominator = target_duration._denominator
         note_durations = [
             _duration.Duration(_, denominator) for _ in proportions.numbers
         ]
+        maker = _makers.NoteMaker()
         notes = maker(0, note_durations)
     tuplet = _score.Tuplet.from_duration(target_duration, notes)
     for leaf in argument:
@@ -1059,7 +1379,7 @@ def replace(argument, recipients, wrappers=False):
         >>> tuplet_1 = abjad.Tuplet((2, 3), "c'4 d'4 e'4")
         >>> tuplet_2 = abjad.Tuplet((2, 3), "d'4 e'4 f'4")
         >>> staff = abjad.Staff([tuplet_1, tuplet_2])
-        >>> leaves = abjad.select(staff).leaves()
+        >>> leaves = abjad.select.leaves(staff)
         >>> abjad.hairpin('p < f', leaves)
         >>> abjad.slur(leaves)
         >>> abjad.show(staff) # doctest: +SKIP
@@ -1254,14 +1574,17 @@ def replace(argument, recipients, wrappers=False):
 
     Returns none.
     """
-    if isinstance(argument, _selection.Selection):
+    if isinstance(argument, (list, _select.Selection)):
         donors = argument
     else:
-        donors = _selection.Selection(argument)
-    assert donors.are_contiguous_same_parent()
-    if not isinstance(recipients, _selection.Selection):
-        recipients = _selection.Selection(recipients)
-    assert recipients.are_contiguous_same_parent()
+        donors = [argument]
+    assert _are_contiguous_same_parent(donors)
+    if not isinstance(recipients, (list, _select.Selection)):
+        if isinstance(recipients, _score.Component):
+            recipients = [recipients]
+        else:
+            recipients = list(recipients)
+    assert _are_contiguous_same_parent(recipients)
     if not donors:
         return
     if wrappers is True:
@@ -1272,7 +1595,7 @@ def replace(argument, recipients, wrappers=False):
         donor = donors[0]
         wrappers = _get.wrappers(donor)
         recipient = recipients[0]
-    parent, start, stop = donors._get_parent_and_start_stop_indices()
+    parent, start, stop = _get_parent_and_start_stop_indices(donors)
     assert parent is not None, repr(donors)
     parent.__setitem__(slice(start, stop + 1), recipients)
     if not wrappers:
@@ -1342,7 +1665,7 @@ def scale(argument, multiplier) -> None:
                 d'8
             }
 
-        >>> logical_tie = abjad.select(staff[0]).logical_tie()
+        >>> logical_tie = abjad.select.logical_tie(staff[0])
         >>> logical_tie = abjad.mutate.scale(logical_tie, abjad.Multiplier(3, 2))
         >>> abjad.show(staff) # doctest: +SKIP
 
@@ -1471,7 +1794,7 @@ def scale(argument, multiplier) -> None:
     if hasattr(argument, "_scale"):
         argument._scale(multiplier)
     else:
-        assert isinstance(argument, _selection.Selection)
+        assert isinstance(argument, (list, _select.Selection))
         for component in argument:
             component._scale(multiplier)
 
@@ -1867,24 +2190,21 @@ def split(argument, durations, cyclic=False):
     """
     components = argument
     if isinstance(components, _score.Component):
-        components = _selection.Selection(components)
+        components = [components]
     assert all(isinstance(_, _score.Component) for _ in components)
-    if not isinstance(components, _selection.Selection):
-        components = _selection.Selection(components)
     durations = [_duration.Duration(_) for _ in durations]
     assert len(durations), repr(durations)
     total_component_duration = _get.duration(components)
     total_split_duration = sum(durations)
     if cyclic:
-        durations = _sequence.Sequence(durations)
-        durations = durations.repeat_to_weight(total_component_duration)
+        durations = _sequence.repeat_to_weight(durations, total_component_duration)
         durations = list(durations)
     elif total_split_duration < total_component_duration:
         final_offset = total_component_duration - sum(durations)
         durations.append(final_offset)
     elif total_component_duration < total_split_duration:
         weight = total_component_duration
-        durations = _sequence.Sequence(durations).truncate(weight=weight)
+        durations = _sequence.truncate(durations, weight=weight)
         durations = list(durations)
     # keep copy of durations to partition result components
     durations_copy = durations[:]
@@ -1928,8 +2248,8 @@ def split(argument, durations, cyclic=False):
                 current_duration = duration_
                 additional_required_duration = current_duration
                 additional_required_duration -= local_split_duration
-                split_durations = _sequence.Sequence(durations)
-                split_durations = split_durations.split(
+                split_durations = _sequence.split(
+                    durations,
                     [additional_required_duration],
                     cyclic=False,
                     overhang=True,
@@ -1976,12 +2296,10 @@ def split(argument, durations, cyclic=False):
     if len(remaining_components):
         result.append(remaining_components)
     # partition split components according to input durations
-    result = _sequence.Sequence(result).flatten(depth=-1)
-    result = _selection.Selection(result).partition_by_durations(
-        durations_copy, fill=_enums.Exact
-    )
+    result = _sequence.flatten(result, depth=-1)
+    result = _select.partition_by_durations(result, durations_copy, fill=_enums.Exact)
     # return list of shards
-    assert all(isinstance(_, _selection.Selection) for _ in result)
+    assert all(isinstance(_, (list, _select.Selection)) for _ in result)
     return result
 
 
@@ -1997,7 +2315,7 @@ def swap(argument, container):
         >>> staff.append(abjad.Container("c'4 d'4 e'4"))
         >>> staff.append(abjad.Container("d'4 e'4 f'4"))
         >>> abjad.attach(abjad.TimeSignature((3, 4)), staff[0][0])
-        >>> leaves = abjad.select(staff).leaves()
+        >>> leaves = abjad.select.leaves(staff)
         >>> abjad.hairpin('p < f', leaves)
         >>> measures = staff[:]
         >>> abjad.slur(leaves)
@@ -2058,16 +2376,16 @@ def swap(argument, container):
 
     Returns none.
     """
-    if isinstance(argument, _selection.Selection):
+    if isinstance(argument, (list, _select.Selection)):
         donors = argument
     else:
-        donors = _selection.Selection(argument)
-    assert donors.are_contiguous_same_parent()
+        assert isinstance(argument, _score.Component)
+        donors = [argument]
+    assert _are_contiguous_same_parent(donors)
     assert isinstance(container, _score.Container)
     assert not container, repr(container)
-    donors._give_components_to_empty_container(container)
-    # donors._give_dominant_spanners([container])
-    donors._give_position_in_parent_to_container(container)
+    _give_components_to_empty_container(donors, container)
+    _give_position_in_parent_to_container(donors, container)
 
 
 def transpose(argument, interval):
@@ -2127,13 +2445,13 @@ def transpose(argument, interval):
     Returns none.
     """
     named_interval = _pitch.NamedInterval(interval)
-    for x in iterate_.components(argument, (_score.Note, _score.Chord)):
-        if isinstance(x, _score.Note):
-            old_written_pitch = x.note_head.written_pitch
+    for item in iterate_.components(argument, (_score.Note, _score.Chord)):
+        if isinstance(item, _score.Note):
+            old_written_pitch = item.note_head.written_pitch
             new_written_pitch = old_written_pitch.transpose(named_interval)
-            x.note_head.written_pitch = new_written_pitch
+            item.note_head.written_pitch = new_written_pitch
         else:
-            for note_head in x.note_heads:
+            for note_head in item.note_heads:
                 old_written_pitch = note_head.written_pitch
                 new_written_pitch = old_written_pitch.transpose(named_interval)
                 note_head.written_pitch = new_written_pitch
@@ -2311,7 +2629,7 @@ def wrap(argument, container):
         wrap:
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> leaves = abjad.select(staff).leaves()
+        >>> leaves = abjad.select.leaves(staff)
         >>> abjad.attach(abjad.TimeSignature((3, 8)), leaves[0])
         >>> container = abjad.Container()
         >>> abjad.mutate.wrap(leaves, container)
@@ -2337,7 +2655,7 @@ def wrap(argument, container):
         ...     time_signature = abjad.get.effective(component, prototype)
         ...     print(component, time_signature)
         ...
-        <Staff{1}> 3/8
+        Staff("{ c'4 d'4 e'4 f'4 }") 3/8
         Container("c'4 d'4 e'4 f'4") 3/8
         c'4 3/8
         d'4 3/8
@@ -2349,19 +2667,19 @@ def wrap(argument, container):
     if not isinstance(container, _score.Container) or 0 < len(container):
         raise Exception(f"must be empty container: {container!r}.")
     if isinstance(argument, _score.Component):
-        selection = _selection.Selection(argument)
+        selection = [argument]
     else:
         selection = argument
-    assert isinstance(selection, _selection.Selection), repr(selection)
-    parent, start, stop = selection._get_parent_and_start_stop_indices(
-        ignore_before_after_grace=True
+    assert isinstance(selection, (list, _select.Selection)), repr(selection)
+    parent, start, stop = _get_parent_and_start_stop_indices(
+        selection, ignore_before_after_grace=True
     )
-    if not selection.are_contiguous_logical_voice(ignore_before_after_grace=True):
+    if not _are_contiguous_logical_voice(selection, ignore_before_after_grace=True):
         message = "must be contiguous components in same logical voice:\n"
         message += f"   {selection!r}."
         raise Exception(message)
     container._components = list(selection)
-    container[:]._set_parents(container)
+    _set_parents(container)
     if parent is not None:
         parent._components.insert(start, container)
         container._set_parent(parent)
