@@ -4,12 +4,13 @@ from . import _iterate
 from . import bind as _bind
 from . import duration as _duration
 from . import format as _format
+from . import iterate as iterate_
 from . import mutate as _mutate
 from . import overrides as _overrides
 from . import parentage as _parentage
-from . import pitch as _pitch
+from . import pcollections as _pcollections
 from . import score as _score
-from . import selection as _selection
+from . import select as _select
 from . import spanners as _spanners
 from . import tag as _tag
 from . import typings as _typings
@@ -207,7 +208,7 @@ class OnBeatGraceContainer(_score.Container):
         else:
             assert container.index(self) == 1
             anchor_voice = container[0]
-        anchor_leaf = _selection.Selection(anchor_voice).leaf(0, grace=False)
+        anchor_leaf = _select.leaf(anchor_voice, 0, grace=False)
         return anchor_leaf
 
     @staticmethod
@@ -249,8 +250,8 @@ class OnBeatGraceContainer(_score.Container):
                 chord = _score.Chord(first_grace)
                 _mutate.replace(first_grace, chord)
                 first_grace = chord
-            selection = _selection.Selection(anchor_leaf)
-            anchor_pitches = _pitch.PitchSet.from_selection(selection)
+            generator = iterate_.pitches(anchor_leaf)
+            anchor_pitches = _pcollections.PitchSet.from_pitches(generator)
             highest_pitch = list(sorted(anchor_pitches))[-1]
             if highest_pitch not in first_grace.note_heads:
                 first_grace.note_heads.append(highest_pitch)
@@ -261,7 +262,7 @@ class OnBeatGraceContainer(_score.Container):
     def _set_leaf_durations(self):
         if self.leaf_duration is None:
             return
-        for leaf in _selection.Selection(self).leaves():
+        for leaf in _select.leaves(self):
             duration = leaf._get_duration()
             if duration != self.leaf_duration:
                 multiplier = self.leaf_duration / duration
@@ -277,9 +278,6 @@ class OnBeatGraceContainer(_score.Container):
         return self._leaf_duration
 
 
-### FACTORY FUNCTIONS ###
-
-
 def on_beat_grace_container(
     contents,
     anchor_voice_selection,
@@ -823,9 +821,8 @@ def on_beat_grace_container(
     def _site(n):
         return _tag.Tag(f"abjad.on_beat_grace_container({n})")
 
-    assert isinstance(anchor_voice_selection, _selection.Selection)
-    if not anchor_voice_selection.are_contiguous_same_parent(
-        ignore_before_after_grace=True
+    if not _mutate._are_contiguous_same_parent(
+        anchor_voice_selection, ignore_before_after_grace=True
     ):
         message = "selection must be contiguous in same parent:\n"
         message += f"   {repr(anchor_voice_selection)}"
@@ -833,8 +830,6 @@ def on_beat_grace_container(
     on_beat_grace_container = OnBeatGraceContainer(
         contents, leaf_duration=leaf_duration
     )
-    if not isinstance(anchor_voice_selection, _selection.Selection):
-        raise Exception(f"must be selection:\n {repr(anchor_voice_selection)}")
     anchor_leaf = _iterate._get_leaf(anchor_voice_selection, 0)
     anchor_voice = _parentage.Parentage(anchor_leaf).get(_score.Voice)
     if anchor_voice.name is None:
