@@ -1,23 +1,105 @@
 import copy
+import dataclasses
 import typing
 
 from . import bundle as _bundle
 from . import enums as _enums
 from . import format as _format
-from . import fsv as _fsv
 from . import lyenv as _lyenv
 from . import string as _string
 from . import tag as _tag
 
 
 def format_embedded_scheme_value(value):
-    result = _fsv.format_scheme_value(value)
+    """
+    Formats embedded Scheme ``value``.
+    """
+    result = format_scheme_value(value)
     if isinstance(value, bool):
         result = "#" + result
     return result
 
 
+def format_scheme_value(
+    value: typing.Any, force_quotes: bool = False, verbatim: bool = False
+) -> str:
+    r"""
+    Formats ``value`` in a scheme-like way.
+
+    ..  container:: example
+
+        Some basic values:
+
+        >>> abjad.overrides.format_scheme_value(1)
+        '1'
+
+        >>> abjad.overrides.format_scheme_value('foo')
+        'foo'
+
+        >>> abjad.overrides.format_scheme_value('bar baz')
+        '"bar baz"'
+
+        >>> abjad.overrides.format_scheme_value([1.5, True, False])
+        '(1.5 #t #f)'
+
+    ..  container:: example
+
+        Strings without whitespace can be forcibly quoted via the
+        ``force_quotes`` keyword:
+
+        >>> abjad.overrides.format_scheme_value(
+        ...     'foo',
+        ...     force_quotes=True,
+        ... )
+        '"foo"'
+
+    ..  container:: example
+
+        Set verbatim to true to format value exactly (with only hash
+        preprended):
+
+        >>> string = '(lambda (grob) (grob-interpret-markup grob'
+        >>> string += r' #{ \markup \musicglyph #"noteheads.s0harmonic" #}))'
+        >>> abjad.overrides.format_scheme_value(string, verbatim=True)
+        '(lambda (grob) (grob-interpret-markup grob #{ \\markup \\musicglyph #"noteheads.s0harmonic" #}))'
+
+    ..  container:: example
+
+        Hash symbol at the beginning of a string does not result in quoted
+        output:
+
+        >>> string = '#1-finger'
+        >>> abjad.overrides.format_scheme_value(string)
+        '#1-finger'
+
+    """
+    if isinstance(value, str) and verbatim:
+        return value
+    elif isinstance(value, str) and not verbatim:
+        value = value.replace('"', r"\"")
+        if value.startswith("#"):
+            pass
+        elif value.startswith("\\"):
+            pass
+        elif force_quotes or " " in value or "#" in value:
+            return f'"{value}"'
+        return value
+    elif value is True:
+        return "#t"
+    elif value is False:
+        return "#f"
+    elif isinstance(value, (list, tuple)):
+        string = " ".join(format_scheme_value(_) for _ in value)
+        return f"({string})"
+    elif value is None:
+        return "#f"
+    return str(value)
+
+
 def format_lilypond_attribute(attribute) -> str:
+    """
+    Formats LilyPond ``attribute``.
+    """
     assert isinstance(attribute, str), repr(attribute)
     attribute = attribute.replace("__", ".")
     result = attribute.replace("_", "-")
@@ -49,6 +131,9 @@ lilypond_color_constants = (
 
 
 def format_lilypond_value(argument) -> str:
+    """
+    Formats LilyPond value.
+    """
     if "_get_lilypond_format" in dir(argument):
         return argument._get_lilypond_format()
     if argument is True:
@@ -73,13 +158,14 @@ def format_lilypond_value(argument) -> str:
 def make_lilypond_override_string(
     grob, attribute, value, context=None, once=False
 ) -> str:
-    # camel_name = _string.String(grob).to_upper_camel_case()
-    # assert grob == camel_name, repr((grob, camel_name))
-    grob = _string.String(grob).to_upper_camel_case()
+    """
+    Makes LilyPond override string.
+    """
+    grob = _string.to_upper_camel_case(grob)
     attribute = format_lilypond_attribute(attribute)
     value = format_lilypond_value(value)
     if context is not None:
-        context = _string.String(context).capitalize_start() + "."
+        context = _string.capitalize_start(context) + "."
     else:
         context = ""
     if once is True:
@@ -91,14 +177,13 @@ def make_lilypond_override_string(
 
 
 def make_lilypond_revert_string(grob, attribute, context=None) -> str:
-    # camel_name = _string.String(grob).to_upper_camel_case()
-    # assert grob == camel_name, repr((grob, camel_name))
-    grob = _string.String(grob).to_upper_camel_case()
+    """
+    Makes LilyPond revert string.
+    """
+    grob = _string.to_upper_camel_case(grob)
     dotted = format_lilypond_attribute(attribute)
     if context is not None:
-        # camel_name = _string.String(context).to_upper_camel_case()
-        # assert context == camel_name, repr((context, camel_name))
-        context = _string.String(context).to_upper_camel_case()
+        context = _string.to_upper_camel_case(context)
         context += "."
     else:
         context = ""
@@ -109,10 +194,11 @@ def make_lilypond_revert_string(grob, attribute, context=None) -> str:
 def make_lilypond_tweak_string(
     attribute, value, *, directed=True, grob=None, literal=None
 ) -> str:
+    """
+    Makes LilyPond tweak string.
+    """
     if grob is not None:
-        # camel_name = _string.String(grob).to_upper_camel_case()
-        # assert grob == camel_name, repr((grob, camel_name))
-        grob = _string.String(grob).to_upper_camel_case()
+        grob = _string.to_upper_camel_case(grob)
         grob += "."
     else:
         grob = ""
@@ -125,6 +211,7 @@ def make_lilypond_tweak_string(
     return string
 
 
+@dataclasses.dataclass(slots=True, unsafe_hash=True)
 class LilyPondLiteral:
     r"""
     LilyPond literal.
@@ -167,7 +254,7 @@ class LilyPondLiteral:
         >>> literal = abjad.LilyPondLiteral(
         ...     "% before all formatting",
         ...     format_slot="absolute_before",
-        ...     )
+        ... )
         >>> abjad.attach(literal, staff[0])
         >>> literal = abjad.LilyPondLiteral("", format_slot="absolute_after")
         >>> abjad.attach(literal, staff[-1])
@@ -270,11 +357,95 @@ class LilyPondLiteral:
             f'4
         }
 
+    ..  container:: example
+
+        >>> staff = abjad.Staff("c'4 d' e' f'")
+        >>> literal = abjad.LilyPondLiteral(r"\f", "after", directed=True)
+        >>> abjad.tweak(literal).color = "#blue"
+        >>> abjad.attach(literal, staff[0])
+        >>> abjad.show(staff) # doctest: +SKIP
+
+        ..  docs::
+
+            >>> string = abjad.lilypond(staff)
+            >>> print(string)
+            \new Staff
+            {
+                c'4
+                - \tweak color #blue
+                \f
+                d'4
+                e'4
+                f'4
+            }
+
+    ..  container:: example
+
+        Directed literal:
+
+        >>> staff = abjad.Staff("c'4 d' e' f'")
+        >>> literal = abjad.LilyPondLiteral(r"\f", "after", directed=True)
+        >>> abjad.tweak(literal).color = "#blue"
+        >>> abjad.tweak(literal).DynamicLineSpanner.staff_padding = 5
+        >>> abjad.attach(literal, staff[0])
+        >>> abjad.show(staff) # doctest: +SKIP
+
+        ..  docs::
+
+            >>> string = abjad.lilypond(staff)
+            >>> print(string)
+            \new Staff
+            {
+                c'4
+                - \tweak DynamicLineSpanner.staff-padding 5
+                - \tweak color #blue
+                \f
+                d'4
+                e'4
+                f'4
+            }
+
+    ..  container:: example
+
+        Nondirected literal:
+
+        >>> staff = abjad.Staff("c'4 d' e' f'")
+        >>> literal = abjad.LilyPondLiteral(
+        ...     r"\breathe",
+        ...     "after",
+        ...     directed=False,
+        ... )
+        >>> abjad.tweak(literal).color = "#blue"
+        >>> abjad.attach(literal, staff[0])
+        >>> abjad.show(staff) # doctest: +SKIP
+
+        ..  docs::
+
+            >>> string = abjad.lilypond(staff)
+            >>> print(string)
+            \new Staff
+            {
+                c'4
+                \tweak color #blue
+                \breathe
+                d'4
+                e'4
+                f'4
+            }
+
+        Proper use of the ``directed`` property entails searching the LilyPond
+        docs to understand whether LilyPond treats any particular command as
+        directed or not. Most LilyPond commands are directed. LilyPond insists
+        that a few commands (include ``\breathe``, ``\key``, ``\mark``) must
+        not be directed.
+
     """
 
-    ### CLASS VARIABLES ###
-
-    __slots__ = ("_argument", "_directed", "_format_slot", "_tweaks")
+    argument: typing.Union[str, typing.List[str]] = ""
+    # TODO: probaby change default to "before"
+    format_slot: str = "opening"
+    directed: bool = False
+    tweaks: typing.Optional["TweakInterface"] = None
 
     _allowable_format_slots = (
         "absolute_after",
@@ -285,55 +456,15 @@ class LilyPondLiteral:
         "opening",
     )
 
+    _is_dataclass = True
     _can_attach_to_containers = True
-
     _format_leaf_children = False
 
-    ### INITIALIZER ###
-
-    def __init__(
-        self,
-        argument: typing.Union[str, typing.List[str]] = "",
-        # TODO: probaby change default to "before"
-        format_slot: str = "opening",
-        *,
-        directed: bool = None,
-        tweaks: "TweakInterface" = None,
-    ) -> None:
-        self._argument = argument
-        assert format_slot in self._allowable_format_slots, repr(format_slot)
-        self._format_slot = format_slot
-        if directed is not None:
-            directed = bool(directed)
-        self._directed = directed
-        if tweaks is not None:
-            assert isinstance(tweaks, TweakInterface), repr(tweaks)
-        self._tweaks = TweakInterface.set_tweaks(self, tweaks)
-
-    ### SPECIAL METHODS ###
-
-    def __eq__(self, argument) -> bool:
-        """
-        Compares ``argument`` and ``format_slot``.
-        """
-        if isinstance(argument, type(self)):
-            if self.argument == argument.argument:
-                return self.format_slot == argument.format_slot
-        return False
-
-    def __hash__(self) -> int:
-        """
-        Hashes LilyPond literal.
-        """
-        return hash(self.__class__.__name__ + str(self))
-
-    def __repr__(self) -> str:
-        """
-        Gets interpreter representation.
-        """
-        return _format.get_repr(self)
-
-    ### PRIVATE METHODS ###
+    def __post_init__(self):
+        assert self.format_slot in self._allowable_format_slots, repr(self.format_slot)
+        if self.directed is not None:
+            self.directed = bool(self.directed)
+        self.tweaks = TweakInterface.set_dataclass_tweaks(self, self.tweaks)
 
     # TODO: activate this:
     #    def _before_attach(self, component):
@@ -348,12 +479,6 @@ class LilyPondLiteral:
         assert isinstance(self.argument, list)
         return self.argument[:]
 
-    def _get_format_specification(self):
-        return _format.FormatSpecification(
-            storage_format_args_values=[self.argument],
-            storage_format_is_not_indented=True,
-        )
-
     def _get_lilypond_format_bundle(self, component=None):
         bundle = _bundle.LilyPondFormatBundle()
         format_slot = bundle.get(self.format_slot)
@@ -364,133 +489,6 @@ class LilyPondLiteral:
         format_slot.commands.extend(pieces)
         return bundle
 
-    ### PUBLIC PROPERTIES ###
-
-    @property
-    def argument(self) -> typing.Union[str, typing.List[str]]:
-        r"""
-        Gets argument of LilyPond literal.
-
-        ..  container:: example
-
-            >>> literal = abjad.LilyPondLiteral(r"\slurDotted")
-            >>> literal.argument
-            '\\slurDotted'
-
-        """
-        return self._argument
-
-    @property
-    def directed(self) -> typing.Optional[bool]:
-        r"""
-        Is true when literal is directed.
-
-        ..  container:: example
-
-            Directed literal:
-
-            >>> staff = abjad.Staff("c'4 d' e' f'")
-            >>> literal = abjad.LilyPondLiteral(r"\f", "after", directed=True)
-            >>> abjad.tweak(literal).color = "#blue"
-            >>> abjad.tweak(literal).DynamicLineSpanner.staff_padding = 5
-            >>> abjad.attach(literal, staff[0])
-            >>> abjad.show(staff) # doctest: +SKIP
-
-            ..  docs::
-
-                >>> string = abjad.lilypond(staff)
-                >>> print(string)
-                \new Staff
-                {
-                    c'4
-                    - \tweak DynamicLineSpanner.staff-padding 5
-                    - \tweak color #blue
-                    \f
-                    d'4
-                    e'4
-                    f'4
-                }
-
-        ..  container:: example
-
-            Nondirected literal:
-
-            >>> staff = abjad.Staff("c'4 d' e' f'")
-            >>> literal = abjad.LilyPondLiteral(
-            ...     r"\breathe",
-            ...     "after",
-            ...     directed=False,
-            ...     )
-            >>> abjad.tweak(literal).color = "#blue"
-            >>> abjad.attach(literal, staff[0])
-            >>> abjad.show(staff) # doctest: +SKIP
-
-            ..  docs::
-
-                >>> string = abjad.lilypond(staff)
-                >>> print(string)
-                \new Staff
-                {
-                    c'4
-                    \tweak color #blue
-                    \breathe
-                    d'4
-                    e'4
-                    f'4
-                }
-
-        Proper use of the ``directed`` property entails searching the LilyPond
-        docs to understand whether LilyPond treats any particular command as
-        directed or not. Most LilyPond commands are directed. LilyPond insists
-        that a few commands (include ``\breathe``, ``\key``, ``\mark``) must
-        not be directed.
-        """
-        return self._directed
-
-    @property
-    def format_slot(self) -> str:
-        r"""
-        Gets format slot of LilyPond literal.
-
-        ..  container:: example
-
-            >>> literal = abjad.LilyPondLiteral(r"\slurDotted")
-            >>> literal.format_slot
-            'opening'
-
-        """
-        return self._format_slot
-
-    @property
-    def tweaks(self) -> typing.Optional["TweakInterface"]:
-        r"""
-        Gets tweaks.
-
-        ..  container:: example
-
-            >>> staff = abjad.Staff("c'4 d' e' f'")
-            >>> literal = abjad.LilyPondLiteral(r"\f", "after", directed=True)
-            >>> abjad.tweak(literal).color = "#blue"
-            >>> abjad.attach(literal, staff[0])
-            >>> abjad.show(staff) # doctest: +SKIP
-
-            ..  docs::
-
-                >>> string = abjad.lilypond(staff)
-                >>> print(string)
-                \new Staff
-                {
-                    c'4
-                    - \tweak color #blue
-                    \f
-                    d'4
-                    e'4
-                    f'4
-                }
-
-        """
-        return self._tweaks
-
 
 class Interface:
     """
@@ -666,8 +664,8 @@ class LilyPondOverride:
         self,
         lilypond_type: str = None,
         grob_name: str = "NoteHead",
-        once: bool = None,
-        is_revert: bool = None,
+        once: bool = False,
+        is_revert: bool = False,
         property_path: typing.Union[str, typing.Iterable[str]] = "color",
         value: typing.Any = "#red",
     ) -> None:
@@ -676,12 +674,8 @@ class LilyPondOverride:
         self._lilypond_type = lilypond_type
         assert grob_name
         self._grob_name = str(grob_name)
-        if once is not None:
-            once = bool(once)
-        self._once = once
-        if is_revert is not None:
-            is_revert = bool(is_revert)
-        self._is_revert = is_revert
+        self._once = bool(once)
+        self._is_revert = bool(is_revert)
         if isinstance(property_path, str):
             property_path_: typing.Tuple[str, ...] = (property_path,)
         else:
@@ -750,7 +744,7 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
+            ... )
             >>> override.grob_name
             'Glissando'
 
@@ -758,7 +752,7 @@ class LilyPondOverride:
         return self._grob_name
 
     @property
-    def is_revert(self) -> typing.Optional[bool]:
+    def is_revert(self) -> bool:
         r"""
         Is true if grob override is a grob revert.
 
@@ -768,16 +762,16 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
-            >>> bool(override.is_revert)
+            ... )
+            >>> override.is_revert
             False
 
             >>> override = abjad.LilyPondOverride(
             ...     grob_name="Glissando",
             ...     is_revert=True,
             ...     property_path="style",
-            ...     )
-            >>> bool(override.is_revert)
+            ... )
+            >>> override.is_revert
             True
 
         """
@@ -808,7 +802,7 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
+            ... )
             >>> override.lilypond_type is None
             True
 
@@ -816,7 +810,7 @@ class LilyPondOverride:
         return self._lilypond_type
 
     @property
-    def once(self) -> typing.Optional[bool]:
+    def once(self) -> bool:
         r"""
         Is true when grob override is to be applied only once.
 
@@ -840,7 +834,7 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
+            ... )
             >>> bool(override.once)
             False
 
@@ -896,7 +890,7 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
+            ... )
             >>> override.override_string
             "\\override Glissando.style = #'zigzag"
 
@@ -938,7 +932,7 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
+            ... )
             >>> override.revert_format_pieces
             ('\\revert Glissando.style',)
 
@@ -957,7 +951,7 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
+            ... )
             >>> override.revert_string
             '\\revert Glissando.style'
 
@@ -1000,7 +994,7 @@ class LilyPondOverride:
             ...     grob_name="Glissando",
             ...     property_path="style",
             ...     value="#'zigzag",
-            ...     )
+            ... )
             >>> override.tweak_string()
             "- \\tweak style #'zigzag"
 
@@ -1010,7 +1004,7 @@ class LilyPondOverride:
             ...     grob_name="RehearsalMark",
             ...     property_path="color",
             ...     value="#red",
-            ...     )
+            ... )
             >>> override.tweak_string(directed=False)
             '\\tweak color #red'
 
@@ -1022,7 +1016,7 @@ class LilyPondOverride:
             ...     grob_name="TextSpann",
             ...     property_path=("bound-details", "left-broken", "text"),
             ...     value=abjad.LilyPondLiteral(r"\markup \upright pont."),
-            ...     )
+            ... )
             >>> override.tweak_string(directed=False)
             '\\tweak bound-details.left-broken.text \\markup \\upright pont.'
 
@@ -1212,8 +1206,7 @@ class OverrideInterface(Interface):
         Note that the dot-chained user syntax is unproblematic. But the class of each
         manager returned in the chain is likely to be surprising at first encounter.
         """
-        camel_name = _string.String(name).to_upper_camel_case()
-        # assert name == camel_name, repr((name, camel_name))
+        camel_name = _string.to_upper_camel_case(name)
         if name.startswith("_"):
             try:
                 return vars(self)[name]
@@ -1414,8 +1407,7 @@ class SettingInterface(Interface):
             Markup(string='\\markup "Vn. I"', direction=None, tweaks=None)
 
         """
-        camel_name = _string.String(name).to_upper_camel_case()
-        # assert name == camel_name, repr((name, camel_name))
+        camel_name = _string.to_upper_camel_case(name)
         if name.startswith("_"):
             try:
                 return vars(self)[name]
@@ -1568,7 +1560,7 @@ class TweakInterface(Interface):
 
         >>> markup = abjad.Markup(r"\markup Allegro", direction=abjad.Up)
         >>> abjad.tweak(markup)
-        TweakInterface(('_literal', None))
+        TweakInterface(('_literal', False))
 
         Set an attribute like this:
 
@@ -1577,7 +1569,7 @@ class TweakInterface(Interface):
         The state of the tweak manager has changed:
 
         >>> abjad.tweak(markup)
-        TweakInterface(('_literal', None), ('color', '#red'))
+        TweakInterface(('_literal', False), ('color', '#red'))
 
         And the value of the attribute just set is available like this:
 
@@ -1597,13 +1589,10 @@ class TweakInterface(Interface):
     ### INITIALIZER ###
 
     def __init__(
-        self, *, deactivate: bool = None, literal: bool = None, tag: _tag.Tag = None
+        self, *, deactivate: bool = False, literal: bool = False, tag: _tag.Tag = None
     ) -> None:
-        if deactivate is not None:
-            self._currently_deactivated = deactivate
-        if literal is not None:
-            literal = bool(literal)
-        self._literal = literal
+        self._currently_deactivated = bool(deactivate)
+        self._literal = bool(literal)
         if tag is not None:
             self._currently_tagging = tag
 
@@ -1692,24 +1681,24 @@ class TweakInterface(Interface):
             >>> tweaks.color = "#red"
             >>> tweaks.Y_offset = 6
             >>> tweaks
-            TweakInterface(('Y_offset', 6), ('_literal', None), ('color', '#red'))
+            TweakInterface(('Y_offset', 6), ('_literal', False), ('color', '#red'))
 
             Use the ``abjad.tweak()`` factory function for a shortcut:
 
             >>> tweaks = abjad.tweak("#red").color
             >>> tweaks
-            TweakInterface(('_literal', None), ('color', '#red'))
+            TweakInterface(('_literal', False), ('color', '#red'))
 
             >>> tweaks.Y_offset = 6
             >>> tweaks
-            TweakInterface(('Y_offset', 6), ('_literal', None), ('color', '#red'))
+            TweakInterface(('Y_offset', 6), ('_literal', False), ('color', '#red'))
 
         ..  container:: example
 
             Set long LilyPond grob chains like this:
 
             >>> abjad.tweak(False).bound_details__left_broken__text
-            TweakInterface(('_literal', None), ('bound_details__left_broken__text', False))
+            TweakInterface(('_literal', False), ('bound_details__left_broken__text', False))
 
         """
         if name == "_currently_deactivated":
@@ -1723,8 +1712,7 @@ class TweakInterface(Interface):
             self.__setattr__(name, _pending_value)
             delattr(self, "_pending_value")
             return self
-        camel_name = _string.String(name).to_upper_camel_case()
-        # assert name == camel_name, repr((name, camel_name))
+        camel_name = _string.to_upper_camel_case(name)
         if name.startswith("_"):
             try:
                 return vars(self)[name]
@@ -1753,10 +1741,10 @@ class TweakInterface(Interface):
             Allows LilyPond colors:
 
             >>> abjad.tweak("#blue").color
-            TweakInterface(('_literal', None), ('color', '#blue'))
+            TweakInterface(('_literal', False), ('color', '#blue'))
 
             >>> abjad.tweak("#(x11-color 'ForestGreen)").color
-            TweakInterface(('_literal', None), ('color', "#(x11-color 'ForestGreen)"))
+            TweakInterface(('_literal', False), ('color', "#(x11-color 'ForestGreen)"))
 
         """
         tag = getattr(self, "_currently_tagging", None)
@@ -1892,10 +1880,10 @@ class TweakInterface(Interface):
 
             >>> tweaks = abjad.tweak("blue").color
             >>> abjad.TweakInterface.set_dataclass_tweaks(glissando, tweaks)
-            TweakInterface(('_literal', None), ('color', 'blue'))
+            TweakInterface(('_literal', False), ('color', 'blue'))
 
             >>> abjad.tweak(glissando)
-            TweakInterface(('_literal', None), ('color', 'blue'))
+            TweakInterface(('_literal', False), ('color', 'blue'))
 
         """
         assert argument._is_dataclass is True, repr(argument)
@@ -2155,20 +2143,20 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
         Returns LilyPond tweak manager:
 
         >>> abjad.tweak(markup_1)
-        TweakInterface(('_literal', None), ('color', '#red'))
+        TweakInterface(('_literal', False), ('color', '#red'))
 
     ..  container:: example
 
         Tweak expressions work like this:
 
         >>> abjad.tweak("#red").color
-        TweakInterface(('_literal', None), ('color', '#red'))
+        TweakInterface(('_literal', False), ('color', '#red'))
 
         >>> abjad.tweak(6).Y_offset
-        TweakInterface(('Y_offset', 6), ('_literal', None))
+        TweakInterface(('Y_offset', 6), ('_literal', False))
 
         >>> abjad.tweak(False).bound_details__left_broken__text
-        TweakInterface(('_literal', None), ('bound_details__left_broken__text', False))
+        TweakInterface(('_literal', False), ('bound_details__left_broken__text', False))
 
     """
     if tag is not None and not isinstance(tag, _tag.Tag):
