@@ -2,7 +2,6 @@ import collections
 import typing
 
 from . import duration as _duration
-from . import format as _format
 from . import math as _math
 from . import score as _score
 
@@ -54,15 +53,13 @@ class Parentage(collections.abc.Sequence):
         ...
         Note('c4')
         Voice('c4', name='Bass_Voice')
-        <Staff-"Bass_Staff"{1}>
-        <Score<<2>>>
+        Staff('{ c4 }', name='Bass_Staff')
+        Score("{ { e'4 } } { { c4 } }", simultaneous=True)
 
     '''
 
     ### CLASS VARIABLES ###
 
-    __documentation_section__ = "Selections"
-
     __slots__ = ("_component", "_components")
 
     ### INITIALIZER ###
@@ -91,11 +88,11 @@ class Parentage(collections.abc.Sequence):
         """
         return len(self.components)
 
-    def __repr__(self) -> str:
+    def __repr__(self):
         """
-        Gets interpreter representation.
+        Gets repr.
         """
-        return _format.get_repr(self)
+        return f"{type(self).__name__}(component={self.component!r})"
 
     ### PRIVATE METHODS ###
 
@@ -186,16 +183,16 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     print(f"{repr(component):30} {repr(parentage.component)}")
-            <Staff{1}>                     <Staff{1}>
-            <Voice-"Music_Voice"{4}>       <Voice-"Music_Voice"{4}>
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }") Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice') Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
             Note("c'4")                    Note("c'4")
-            BeforeGraceContainer("cs'16")        BeforeGraceContainer("cs'16")
+            BeforeGraceContainer("cs'16")  BeforeGraceContainer("cs'16")
             Note("cs'16")                  Note("cs'16")
             Note("d'4")                    Note("d'4")
-            <<<2>>>                        <<<2>>>
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }") Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
             OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
             Chord("<e' g'>16")             Chord("<e' g'>16")
             Note("gs'16")                  Note("gs'16")
@@ -281,91 +278,91 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     components = parentage.components
             ...     print(f"{repr(component)}:")
             ...     for component_ in components:
             ...         print(f"    {repr(component_)}")
-            <Staff{1}>:
-                <Staff{1}>
-            <Voice-"Music_Voice"{4}>:
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }"):
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice'):
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("c'4"):
                 Note("c'4")
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             BeforeGraceContainer("cs'16"):
                 BeforeGraceContainer("cs'16")
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("cs'16"):
                 Note("cs'16")
                 BeforeGraceContainer("cs'16")
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("d'4"):
                 Note("d'4")
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
-            <<<2>>>:
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }"):
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16"):
                 OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Chord("<e' g'>16"):
                 Chord("<e' g'>16")
                 OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("gs'16"):
                 Note("gs'16")
                 OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("a'16"):
                 Note("a'16")
                 OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("as'16"):
                 Note("as'16")
                 OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Voice("e'4", name='Music_Voice'):
                 Voice("e'4", name='Music_Voice')
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("e'4"):
                 Note("e'4")
                 Voice("e'4", name='Music_Voice')
-                <<<2>>>
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("f'4"):
                 Note("f'4")
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             AfterGraceContainer("fs'16"):
                 AfterGraceContainer("fs'16")
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
             Note("fs'16"):
                 Note("fs'16")
                 AfterGraceContainer("fs'16")
-                <Voice-"Music_Voice"{4}>
-                <Staff{1}>
+                Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+                Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
 
         """
         return self._components
@@ -441,16 +438,16 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     print(f"{repr(component):30} {repr(parentage.orphan)}")
-            <Staff{1}>                     True
-            <Voice-"Music_Voice"{4}>       False
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }") True
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice') False
             Note("c'4")                    False
-            BeforeGraceContainer("cs'16")        False
+            BeforeGraceContainer("cs'16")  False
             Note("cs'16")                  False
             Note("d'4")                    False
-            <<<2>>>                        False
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }") False
             OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") False
             Chord("<e' g'>16")             False
             Note("gs'16")                  False
@@ -536,25 +533,25 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     print(f"{repr(component):30} {repr(parentage.parent)}")
-            <Staff{1}>                     None
-            <Voice-"Music_Voice"{4}>       <Staff{1}>
-            Note("c'4")                    <Voice-"Music_Voice"{4}>
-            BeforeGraceContainer("cs'16")        <Voice-"Music_Voice"{4}>
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }") None
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice') Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("c'4")                    Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+            BeforeGraceContainer("cs'16")  Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
             Note("cs'16")                  BeforeGraceContainer("cs'16")
-            Note("d'4")                    <Voice-"Music_Voice"{4}>
-            <<<2>>>                        <Voice-"Music_Voice"{4}>
-            OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") <<<2>>>
+            Note("d'4")                    Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }") Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+            OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
             Chord("<e' g'>16")             OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
             Note("gs'16")                  OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
             Note("a'16")                   OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
             Note("as'16")                  OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16")
-            Voice("e'4", name='Music_Voice') <<<2>>>
+            Voice("e'4", name='Music_Voice') Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }")
             Note("e'4")                    Voice("e'4", name='Music_Voice')
-            Note("f'4")                    <Voice-"Music_Voice"{4}>
-            AfterGraceContainer("fs'16")   <Voice-"Music_Voice"{4}>
+            Note("f'4")                    Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
+            AfterGraceContainer("fs'16")   Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice')
             Note("fs'16")                  AfterGraceContainer("fs'16")
 
         """
@@ -638,19 +635,19 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     print(f"{repr(component):30} {repr(parentage.prolation)}")
-            <Staff{1}>                     Multiplier(1, 1)
-            <Voice-"Music_Voice"{2}>       Multiplier(1, 1)
-            Tuplet('3:2', "c'4 d'4 e'4") Multiplier(2, 3)
+            Staff("{ { 2/3 c'4 d'4 e'4 } { 2/3 { { <f' a'>8 b'8 } { f'4 } } g'4 a'4 } }") Multiplier(1, 1)
+            Voice("{ 2/3 c'4 d'4 e'4 } { 2/3 { { <f' a'>8 b'8 } { f'4 } } g'4 a'4 }", name='Music_Voice') Multiplier(1, 1)
+            Tuplet('3:2', "c'4 d'4 e'4")   Multiplier(2, 3)
             Note("c'4")                    Multiplier(2, 3)
-            BeforeGraceContainer("cs'16")        Multiplier(2, 3)
+            BeforeGraceContainer("cs'16")  Multiplier(2, 3)
             Note("cs'16")                  Multiplier(2, 3)
             Note("d'4")                    Multiplier(2, 3)
             Note("e'4")                    Multiplier(2, 3)
             Tuplet('3:2', "{ { <f' a'>8 b'8 } { f'4 } } g'4 a'4") Multiplier(2, 3)
-            <<<2>>>                        Multiplier(2, 3)
+            Container("{ <f' a'>8 b'8 } { f'4 }") Multiplier(2, 3)
             OnBeatGraceContainer("<f' a'>8 b'8") Multiplier(2, 3)
             Chord("<f' a'>8")              Multiplier(2, 3)
             Note("b'8")                    Multiplier(2, 3)
@@ -737,26 +734,26 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     print(f"{repr(component):30} {repr(parentage.root)}")
-            <Staff{1}>                     <Staff{1}>
-            <Voice-"Music_Voice"{4}>       <Staff{1}>
-            Note("c'4")                    <Staff{1}>
-            BeforeGraceContainer("cs'16")        <Staff{1}>
-            Note("cs'16")                  <Staff{1}>
-            Note("d'4")                    <Staff{1}>
-            <<<2>>>                        <Staff{1}>
-            OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") <Staff{1}>
-            Chord("<e' g'>16")             <Staff{1}>
-            Note("gs'16")                  <Staff{1}>
-            Note("a'16")                   <Staff{1}>
-            Note("as'16")                  <Staff{1}>
-            Voice("e'4", name='Music_Voice') <Staff{1}>
-            Note("e'4")                    <Staff{1}>
-            Note("f'4")                    <Staff{1}>
-            AfterGraceContainer("fs'16")   <Staff{1}>
-            Note("fs'16")                  <Staff{1}>
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }") Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice') Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("c'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            BeforeGraceContainer("cs'16")  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("cs'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("d'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }") Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Chord("<e' g'>16")             Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("gs'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("a'16")                   Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("as'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Voice("e'4", name='Music_Voice') Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("e'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("f'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            AfterGraceContainer("fs'16")   Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("fs'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
 
         """
         root = self.get(n=-1)
@@ -799,11 +796,11 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     count = parentage.count(abjad.Tuplet)
             ...     print(f"{repr(component):55} {repr(count)}")
-            <Staff{2}>                                              0
+            Staff("{ 2/3 c'2 { 2/3 d'8 e'8 f'8 } } { 2/3 c'4 d'4 e'4 }") 0
             Tuplet('3:2', "c'2 { 2/3 d'8 e'8 f'8 }")                1
             Note("c'2")                                             1
             Tuplet('3:2', "d'8 e'8 f'8")                            2
@@ -954,17 +951,17 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     count = parentage.count(abjad.Staff)
             ...     print(f"{repr(component):30} {repr(count)}")
-            <Staff{1}>                     1
-            <Voice-"Music_Voice"{4}>       1
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }") 1
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice') 1
             Note("c'4")                    1
-            BeforeGraceContainer("cs'16")        1
+            BeforeGraceContainer("cs'16")  1
             Note("cs'16")                  1
             Note("d'4")                    1
-            <<<2>>>                        1
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }") 1
             OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") 1
             Chord("<e' g'>16")             1
             Note("gs'16")                  1
@@ -1065,10 +1062,10 @@ class Parentage(collections.abc.Sequence):
                 Voice("c''4 b'4 c''8", name='Red_Voice')
 
                 >>> parentage.get(abjad.Component, 2)
-                <<<2>>>
+                Container("{ c''4 b'4 c''8 } { e'4 f'4 e'8 }")
 
                 >>> parentage.get(abjad.Component, 3)
-                <Voice-"Red_Voice"{4}>
+                Voice("e''8 d''8 { { c''4 b'4 c''8 } { e'4 f'4 e'8 } } d''8", name='Red_Voice')
 
                 Returns none with ``n`` greater than score depth:
 
@@ -1084,12 +1081,12 @@ class Parentage(collections.abc.Sequence):
                 Returns score root with ``n=-1``:
 
                 >>> parentage.get(abjad.Component, -1)
-                <Voice-"Red_Voice"{4}>
+                Voice("e''8 d''8 { { c''4 b'4 c''8 } { e'4 f'4 e'8 } } d''8", name='Red_Voice')
 
                 With other negative ``n``:
 
                 >>> parentage.get(abjad.Component, -2)
-                <<<2>>>
+                Container("{ c''4 b'4 c''8 } { e'4 f'4 e'8 }")
 
                 >>> parentage.get(abjad.Component, -3)
                 Voice("c''4 b'4 c''8", name='Red_Voice')
@@ -1123,7 +1120,7 @@ class Parentage(collections.abc.Sequence):
                 Voice("c''4 b'4 c''8", name='Red_Voice')
 
                 >>> parentage.get(abjad.Voice, 1)
-                <Voice-"Red_Voice"{4}>
+                Voice("e''8 d''8 { { c''4 b'4 c''8 } { e'4 f'4 e'8 } } d''8", name='Red_Voice')
 
                 >>> parentage.get(abjad.Voice, 2) is None
                 True
@@ -1134,7 +1131,7 @@ class Parentage(collections.abc.Sequence):
                 Negative ``n``:
 
                 >>> parentage.get(abjad.Voice, -1)
-                <Voice-"Red_Voice"{4}>
+                Voice("e''8 d''8 { { c''4 b'4 c''8 } { e'4 f'4 e'8 } } d''8", name='Red_Voice')
 
                 >>> parentage.get(abjad.Voice, -2)
                 Voice("c''4 b'4 c''8", name='Red_Voice')
@@ -1211,27 +1208,27 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     result = parentage.get(abjad.Staff)
             ...     print(f"{repr(component):30} {repr(result)}")
-            <Staff{1}>                     <Staff{1}>
-            <Voice-"Music_Voice"{4}>       <Staff{1}>
-            Note("c'4")                    <Staff{1}>
-            BeforeGraceContainer("cs'16")        <Staff{1}>
-            Note("cs'16")                  <Staff{1}>
-            Note("d'4")                    <Staff{1}>
-            <<<2>>>                        <Staff{1}>
-            OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") <Staff{1}>
-            Chord("<e' g'>16")             <Staff{1}>
-            Note("gs'16")                  <Staff{1}>
-            Note("a'16")                   <Staff{1}>
-            Note("as'16")                  <Staff{1}>
-            Voice("e'4", name='Music_Voice') <Staff{1}>
-            Note("e'4")                    <Staff{1}>
-            Note("f'4")                    <Staff{1}>
-            AfterGraceContainer("fs'16")   <Staff{1}>
-            Note("fs'16")                  <Staff{1}>
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }") Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice') Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("c'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            BeforeGraceContainer("cs'16")  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("cs'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("d'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }") Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Chord("<e' g'>16")             Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("gs'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("a'16")                   Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("as'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Voice("e'4", name='Music_Voice') Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("e'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("f'4")                    Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            AfterGraceContainer("fs'16")   Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
+            Note("fs'16")                  Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }")
 
         """
         if prototype is None:
@@ -1287,17 +1284,8 @@ class Parentage(collections.abc.Sequence):
 
             >>> note = voice[0]
             >>> parentage = abjad.get.parentage(note)
-            >>> logical_voice = parentage.logical_voice()
-            >>> string = abjad.storage(logical_voice)
-            >>> print(string)
-            dict(
-                {
-                    'score': "Score-'Score'",
-                    'staff': "Staff-'Music_Staff'",
-                    'staff group': '',
-                    'voice': "Voice-'Music_Voice'",
-                    }
-                )
+            >>> parentage.logical_voice()
+            {'score': "Score-'Score'", 'staff group': '', 'staff': "Staff-'Music_Staff'", 'voice': "Voice-'Music_Voice'"}
 
         ..  container:: example
 
@@ -1329,65 +1317,20 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> lv = abjad.get.parentage(voice).logical_voice()
-            >>> string = abjad.storage(lv)
-            >>> print(string)
-            dict(
-                {
-                    'score': '',
-                    'staff': '',
-                    'staff group': '',
-                    'voice': "Voice-'Music_Voice'",
-                    }
-                )
+            >>> abjad.get.parentage(voice).logical_voice()
+            {'score': '', 'staff group': '', 'staff': '', 'voice': "Voice-'Music_Voice'"}
 
-            >>> lv = abjad.get.parentage(container_1).logical_voice()
-            >>> string = abjad.storage(lv)
-            >>> print(string)
-            dict(
-                {
-                    'score': '',
-                    'staff': '',
-                    'staff group': '',
-                    'voice': "Voice-'Music_Voice'",
-                    }
-                )
+            >>> abjad.get.parentage(container_1).logical_voice()
+            {'score': '', 'staff group': '', 'staff': '', 'voice': "Voice-'Music_Voice'"}
 
-            >>> lv = abjad.get.parentage(container_1[0]).logical_voice()
-            >>> string = abjad.storage(lv)
-            >>> print(string)
-            dict(
-                {
-                    'score': '',
-                    'staff': '',
-                    'staff group': '',
-                    'voice': "Voice-'Music_Voice'",
-                    }
-                )
+            >>> abjad.get.parentage(container_1[0]).logical_voice()
+            {'score': '', 'staff group': '', 'staff': '', 'voice': "Voice-'Music_Voice'"}
 
-            >>> lv = abjad.get.parentage(container_2).logical_voice()
-            >>> string = abjad.storage(lv)
-            >>> print(string)
-            dict(
-                {
-                    'score': '',
-                    'staff': '',
-                    'staff group': '',
-                    'voice': "Voice-'Music_Voice'",
-                    }
-                )
+            >>> abjad.get.parentage(container_2).logical_voice()
+            {'score': '', 'staff group': '', 'staff': '', 'voice': "Voice-'Music_Voice'"}
 
-            >>> lv = abjad.get.parentage(container_2[0]).logical_voice()
-            >>> string = abjad.storage(lv)
-            >>> print(string)
-            dict(
-                {
-                    'score': '',
-                    'staff': '',
-                    'staff group': '',
-                    'voice': "Voice-'Music_Voice'",
-                    }
-                )
+            >>> abjad.get.parentage(container_2[0]).logical_voice()
+            {'score': '', 'staff group': '', 'staff': '', 'voice': "Voice-'Music_Voice'"}
 
         """
         keys = ("score", "staff group", "staff", "voice")
@@ -1445,12 +1388,12 @@ class Parentage(collections.abc.Sequence):
                     }
                 >>
 
-            >>> for component in abjad.select(score).components():
+            >>> for component in abjad.select.components(score):
             ...     parentage = abjad.get.parentage(component)
             ...     component, parentage.score_index()
             ...
-            (<Score<<2>>>, ())
-            (<Staff{1}>, (0,))
+            (Score("{ { 2/3 c''2 b'2 a'2 } } { c'2 d'2 }", simultaneous=True), ())
+            (Staff("{ 2/3 c''2 b'2 a'2 }"), (0,))
             (Tuplet('3:2', "c''2 b'2 a'2"), (0, 0))
             (Note("c''2"), (0, 0, 0))
             (Note("b'2"), (0, 0, 1))
@@ -1527,17 +1470,17 @@ class Parentage(collections.abc.Sequence):
                     }
                 }
 
-            >>> for component in abjad.select(staff).components():
+            >>> for component in abjad.select.components(staff):
             ...     parentage = abjad.get.parentage(component)
             ...     score_index = parentage.score_index()
             ...     print(f"{repr(component):30} {repr(score_index)}")
-            <Staff{1}>                     ()
-            <Voice-"Music_Voice"{4}>       (0,)
+            Staff("{ c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4 }") ()
+            Voice("c'4 d'4 { { <e' g'>16 gs'16 a'16 as'16 } { e'4 } } f'4", name='Music_Voice') (0,)
             Note("c'4")                    (0, 0)
-            BeforeGraceContainer("cs'16")        (0, 0, 1, '-G')
+            BeforeGraceContainer("cs'16")  (0, 0, 1, '-G')
             Note("cs'16")                  (0, 0, 1, '-G', 0)
             Note("d'4")                    (0, 1)
-            <<<2>>>                        (0, 2)
+            Container("{ <e' g'>16 gs'16 a'16 as'16 } { e'4 }") (0, 2)
             OnBeatGraceContainer("<e' g'>16 gs'16 a'16 as'16") (0, 2, 0)
             Chord("<e' g'>16")             (0, 2, 0, 0)
             Note("gs'16")                  (0, 2, 0, 1)
