@@ -13,7 +13,7 @@ from . import iterate as iterate_
 from . import overrides as _overrides
 from . import parentage as _parentage
 from . import score as _score
-from . import selection as _selection
+from . import select as _select
 from . import sequence as _sequence
 from . import tag as _tag
 from . import typings as _typings
@@ -40,12 +40,12 @@ def _apply_tweaks(argument, tweaks, i=None, total=None):
 
 
 def beam(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    beam_lone_notes: bool = None,
+    beam_lone_notes: bool = False,
     beam_rests: typing.Optional[bool] = True,
     durations: typing.Sequence[_duration.Duration] = None,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     span_beam_count: int = None,
     start_beam: _indicators.StartBeam = None,
     stemlet_length: _typings.Number = None,
@@ -78,9 +78,7 @@ def beam(
     """
     assert callable(selector)
     argument = selector(argument)
-    original_leaves = iterate_.leaves(argument)
-    original_leaves = list(original_leaves)
-
+    original_leaves = list(iterate_.leaves(argument))
     silent_prototype = (_score.MultimeasureRest, _score.Rest, _score.Skip)
 
     def _is_beamable(argument, beam_rests=False):
@@ -96,7 +94,6 @@ def beam(
         if not _is_beamable(leaf, beam_rests=beam_rests):
             continue
         leaves.append(leaf)
-    # print(leaves, "LLL")
     runs = []
     run = []
     run.extend(leaves[:1])
@@ -106,22 +103,15 @@ def beam(
         if this_index + 1 == that_index:
             run.append(leaf)
         else:
-            selection = _selection.Selection(run)
-            runs.append(selection)
+            runs.append(run)
             run = [leaf]
     if run:
-        selection = _selection.Selection(run)
-        runs.append(selection)
-    runs_ = _selection.Selection(runs)
-    assert isinstance(runs_, _selection.Selection), repr(runs_)
-    # print(runs, "RRR", len(runs))
-    # print()
+        runs.append(run)
+    runs_ = runs
     if not beam_lone_notes:
-        result = runs_.nontrivial()
-        assert isinstance(result, _selection.Selection), repr(result)
+        result = _select.nontrivial(runs)
         runs_ = result
     for run in runs_:
-        # print(run, "RRR")
         if all(isinstance(_, silent_prototype) for _ in run):
             continue
         start_leaf = run[0]
@@ -177,11 +167,9 @@ def beam(
     span_beam_count = span_beam_count or 1
     durations = [_duration.Duration(_) for _ in durations]
     leaf_durations = [_._get_duration() for _ in original_leaves]
-    leaf_durations_ = _sequence.Sequence(leaf_durations)
-    parts = leaf_durations_.partition_by_weights(durations, overhang=True)
+    parts = _sequence.partition_by_weights(leaf_durations, durations, overhang=True)
     part_counts = [len(_) for _ in parts]
-    original_leaves = _sequence.Sequence(original_leaves)
-    parts = original_leaves.partition_by_counts(part_counts)
+    parts = _sequence.partition_by_counts(original_leaves, part_counts)
     total_parts = len(parts)
     for i, part in enumerate(parts):
         is_first_part = False
@@ -267,15 +255,15 @@ def beam(
 def glissando(
     argument,
     *tweaks: _overrides.IndexedTweakManager,
-    allow_repeats: bool = None,
-    allow_ties: bool = None,
-    hide_middle_note_heads: bool = None,
-    hide_middle_stems: bool = None,
+    allow_repeats: bool = False,
+    allow_ties: bool = False,
+    hide_middle_note_heads: bool = False,
+    hide_middle_stems: bool = False,
     hide_stem_selector: typing.Callable = None,
-    left_broken: bool = None,
-    parenthesize_repeats: bool = None,
-    right_broken: bool = None,
-    right_broken_show_next: bool = None,
+    left_broken: bool = False,
+    parenthesize_repeats: bool = False,
+    right_broken: bool = False,
+    right_broken_show_next: bool = False,
     style: str = None,
     tag: _tag.Tag = None,
     zero_padding: bool = False,
@@ -1009,11 +997,11 @@ def glissando(
             return False
         return True
 
-    should_hide_stem = _selection.Selection()
+    should_hide_stem = []
     if hide_stem_selector is not None:
         should_hide_stem = hide_stem_selector(argument)
 
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     total = len(leaves) - 1
     for i, leaf in enumerate(leaves):
         if leaf is not leaves[0]:
@@ -1163,9 +1151,9 @@ def glissando(
 
 def hairpin(
     descriptor: str,
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     tag: _tag.Tag = None,
 ) -> None:
     r"""
@@ -1307,7 +1295,7 @@ def hairpin(
 
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
 
@@ -1320,9 +1308,9 @@ def hairpin(
 
 
 def horizontal_bracket(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     start_group: _indicators.StartGroup = None,
     stop_group: _indicators.StopGroup = None,
     tag: _tag.Tag = None,
@@ -1355,7 +1343,7 @@ def horizontal_bracket(
     stop_group = stop_group or _indicators.StopGroup()
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
     _bind.attach(start_group, start_leaf, tag=tag)
@@ -1363,9 +1351,9 @@ def horizontal_bracket(
 
 
 def ottava(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     start_ottava: _indicators.Ottava = _indicators.Ottava(n=1),
     stop_ottava: _indicators.Ottava = _indicators.Ottava(n=0, format_slot="after"),
     tag: _tag.Tag = None,
@@ -1398,7 +1386,7 @@ def ottava(
     assert isinstance(stop_ottava, _indicators.Ottava), repr(stop_ottava)
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
     _bind.attach(start_ottava, start_leaf, tag=tag)
@@ -1406,9 +1394,9 @@ def ottava(
 
 
 def phrasing_slur(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     start_phrasing_slur: _indicators.StartPhrasingSlur = None,
     stop_phrasing_slur: _indicators.StopPhrasingSlur = None,
     tag: _tag.Tag = None,
@@ -1442,7 +1430,7 @@ def phrasing_slur(
     stop_phrasing_slur = _indicators.StopPhrasingSlur()
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
     start_phrasing_slur = start_phrasing_slur or _indicators.StartPhrasingSlur()
@@ -1452,9 +1440,9 @@ def phrasing_slur(
 
 
 def piano_pedal(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     start_piano_pedal: _indicators.StartPianoPedal = None,
     stop_piano_pedal: _indicators.StopPianoPedal = None,
     tag: _tag.Tag = None,
@@ -1494,7 +1482,7 @@ def piano_pedal(
     stop_piano_pedal = stop_piano_pedal or _indicators.StopPianoPedal()
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
     _bind.attach(start_piano_pedal, start_leaf, tag=tag)
@@ -1502,9 +1490,9 @@ def piano_pedal(
 
 
 def slur(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     start_slur: _indicators.StartSlur = None,
     stop_slur: _indicators.StopSlur = None,
     tag: _tag.Tag = None,
@@ -1538,7 +1526,7 @@ def slur(
     stop_slur = stop_slur or _indicators.StopSlur()
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
     _bind.attach(start_slur, start_leaf, tag=tag)
@@ -1546,9 +1534,9 @@ def slur(
 
 
 def text_spanner(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     start_text_span: _indicators.StartTextSpan = None,
     stop_text_span: _indicators.StopTextSpan = None,
     tag: _tag.Tag = None,
@@ -1680,7 +1668,7 @@ def text_spanner(
     stop_text_span = stop_text_span or _indicators.StopTextSpan()
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
     _bind.attach(start_text_span, start_leaf, tag=tag)
@@ -1688,13 +1676,11 @@ def text_spanner(
 
 
 def tie(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
     direction: _enums.VerticalAlignment = None,
-    repeat: typing.Union[
-        bool, _typings.IntegerPair, _selection.DurationInequality
-    ] = None,
-    selector=lambda _: _selection.select(_).leaves(),
+    repeat: bool | _typings.IntegerPair | typing.Callable = False,
+    selector: typing.Callable = lambda _: _select.leaves(_),
     tag: _tag.Tag = None,
 ) -> None:
     r"""
@@ -1880,26 +1866,33 @@ def tie(
             }
 
     """
-    if repeat in (None, False):
-        inequality = _selection.DurationInequality("<", 0)
+    if callable(repeat):
+        pass
+    elif repeat in (None, False):
+
+        def inequality(item):
+            return item < 0
+
     elif repeat is True:
-        inequality = _selection.DurationInequality(">=", 0)
-    elif isinstance(repeat, _selection.DurationInequality):
-        inequality = repeat
+
+        def inequality(item):
+            return item >= 0
+
     else:
         assert isinstance(repeat, tuple) and len(repeat) == 2, repr(repeat)
-        inequality = _selection.DurationInequality(">=", repeat)
-    assert isinstance(inequality, _selection.DurationInequality), repr(inequality)
+
+        def inequality(item):
+            return item >= _duration.Duration(repeat)
+
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
-    assert isinstance(leaves, _selection.Selection), repr(leaves)
+    leaves = _select.leaves(argument)
     if len(leaves) < 2:
         raise Exception(f"must be two or more notes (not {leaves!r}).")
     for leaf in leaves:
         if not isinstance(leaf, (_score.Note, _score.Chord)):
             raise Exception(rf"tie note or chord (not {leaf!r}).")
-    for current_leaf, next_leaf in _sequence.Sequence(leaves).nwise():
+    for current_leaf, next_leaf in _sequence.nwise(leaves):
         duration = current_leaf._get_duration()
         if inequality(duration):
             _bind.detach(_indicators.Tie, current_leaf)
@@ -1914,9 +1907,9 @@ def tie(
 
 
 def trill_spanner(
-    argument: typing.Union[_score.Component, _selection.Selection],
+    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
     *,
-    selector=lambda _: _selection.select(_).leaves(),
+    selector: typing.Callable = lambda _: _select.leaves(_),
     start_trill_span: _indicators.StartTrillSpan = None,
     stop_trill_span: _indicators.StopTrillSpan = None,
     tag: _tag.Tag = None,
@@ -1949,7 +1942,7 @@ def trill_spanner(
     stop_trill_span = stop_trill_span or _indicators.StopTrillSpan()
     assert callable(selector)
     argument = selector(argument)
-    leaves = _selection.Selection(argument).leaves()
+    leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
     _bind.attach(start_trill_span, start_leaf, tag=tag)
