@@ -1,9 +1,9 @@
 from . import enumerate as _enumerate
 from . import iterate as iterate_
 from . import parentage as _parentage
-from . import pitch as _pitch
+from . import pcollections as _pcollections
 from . import score as _score
-from . import selection as _selection
+from . import select as _select
 from . import sequence as _sequence
 
 
@@ -57,8 +57,6 @@ class VerticalMoment:
 
     ### CLASS VARIABLES ###
 
-    __documentation_section__ = "Selections"
-
     __slots__ = ("_components", "_governors", "_offset")
 
     ### INITIALIZER ###
@@ -308,7 +306,7 @@ class VerticalMoment:
         return self._governors
 
     @property
-    def leaves(self):
+    def leaves(self) -> list[_score.Leaf]:
         r"""
         Tuple of zero or more leaves at vertical moment.
 
@@ -378,19 +376,18 @@ class VerticalMoment:
             >>> for moment in abjad.iterate_vertical_moments(score):
             ...     print(moment.offset, moment.leaves)
             ...
-            0 Selection([Note("d''8"), Note("a'4"), Note("f'8")])
-            1/8 Selection([Note("d''8"), Note("a'4"), Note("e'8")])
-            1/6 Selection([Note("c''8"), Note("a'4"), Note("e'8")])
-            1/4 Selection([Note("c''8"), Note("g'4"), Note("d'8")])
-            1/3 Selection([Note("b'8"), Note("g'4"), Note("d'8")])
-            3/8 Selection([Note("b'8"), Note("g'4"), Note("c'8")])
+            0 [Note("d''8"), Note("a'4"), Note("f'8")]
+            1/8 [Note("d''8"), Note("a'4"), Note("e'8")]
+            1/6 [Note("c''8"), Note("a'4"), Note("e'8")]
+            1/4 [Note("c''8"), Note("g'4"), Note("d'8")]
+            1/3 [Note("b'8"), Note("g'4"), Note("d'8")]
+            3/8 [Note("b'8"), Note("g'4"), Note("c'8")]
 
         """
         result = []
         for component in self.components:
             if isinstance(component, _score.Leaf):
                 result.append(component)
-        result = _selection.Selection(result)
         return result
 
     @property
@@ -551,20 +548,20 @@ def iterate_vertical_moments(components, reverse=None):
         >>> for vertical_moment in abjad.iterate_vertical_moments(score):
         ...     vertical_moment.leaves
         ...
-        Selection([Note("d''8"), Note("a'4"), Note("f'8")])
-        Selection([Note("d''8"), Note("a'4"), Note("e'8")])
-        Selection([Note("c''8"), Note("a'4"), Note("e'8")])
-        Selection([Note("c''8"), Note("g'4"), Note("d'8")])
-        Selection([Note("b'8"), Note("g'4"), Note("d'8")])
-        Selection([Note("b'8"), Note("g'4"), Note("c'8")])
+        [Note("d''8"), Note("a'4"), Note("f'8")]
+        [Note("d''8"), Note("a'4"), Note("e'8")]
+        [Note("c''8"), Note("a'4"), Note("e'8")]
+        [Note("c''8"), Note("g'4"), Note("d'8")]
+        [Note("b'8"), Note("g'4"), Note("d'8")]
+        [Note("b'8"), Note("g'4"), Note("c'8")]
 
         >>> for vertical_moment in abjad.iterate_vertical_moments(staff_group):
         ...     vertical_moment.leaves
         ...
-        Selection([Note("a'4"), Note("f'8")])
-        Selection([Note("a'4"), Note("e'8")])
-        Selection([Note("g'4"), Note("d'8")])
-        Selection([Note("g'4"), Note("c'8")])
+        [Note("a'4"), Note("f'8")]
+        [Note("a'4"), Note("e'8")]
+        [Note("g'4"), Note("d'8")]
+        [Note("g'4"), Note("c'8")]
 
     ..  container:: example
 
@@ -617,12 +614,12 @@ def iterate_vertical_moments(components, reverse=None):
         >>> for vertical_moment in abjad.iterate_vertical_moments(score, reverse=True):
         ...     vertical_moment.leaves
         ...
-        Selection([Note("b'8"), Note("g'4"), Note("c'8")])
-        Selection([Note("b'8"), Note("g'4"), Note("d'8")])
-        Selection([Note("c''8"), Note("g'4"), Note("d'8")])
-        Selection([Note("c''8"), Note("a'4"), Note("e'8")])
-        Selection([Note("d''8"), Note("a'4"), Note("e'8")])
-        Selection([Note("d''8"), Note("a'4"), Note("f'8")])
+        [Note("b'8"), Note("g'4"), Note("c'8")]
+        [Note("b'8"), Note("g'4"), Note("d'8")]
+        [Note("c''8"), Note("g'4"), Note("d'8")]
+        [Note("c''8"), Note("a'4"), Note("e'8")]
+        [Note("d''8"), Note("a'4"), Note("e'8")]
+        [Note("d''8"), Note("a'4"), Note("f'8")]
 
         >>> for vertical_moment in abjad.iterate_vertical_moments(
         ...     staff_group,
@@ -630,15 +627,15 @@ def iterate_vertical_moments(components, reverse=None):
         ...     ):
         ...     vertical_moment.leaves
         ...
-        Selection([Note("g'4"), Note("c'8")])
-        Selection([Note("g'4"), Note("d'8")])
-        Selection([Note("a'4"), Note("e'8")])
-        Selection([Note("a'4"), Note("f'8")])
+        [Note("g'4"), Note("c'8")]
+        [Note("g'4"), Note("d'8")]
+        [Note("a'4"), Note("e'8")]
+        [Note("a'4"), Note("f'8")]
 
     Returns tuple.
     '''
     moments = []
-    components = list(_selection.Selection(components).components())
+    components = _select.components(components)
     components.sort(key=lambda _: _._get_timespan().start_offset)
     offset_to_components = dict()
     for component in components:
@@ -705,36 +702,36 @@ def iterate_leaf_pairs(components):
 
         >>> for leaf_pair in abjad.iterate_leaf_pairs(score):
         ...     leaf_pair
-        Selection([Note("c'8"), Note('c4')])
-        Selection([Note("c'8"), Note("d'8")])
-        Selection([Note('c4'), Note("d'8")])
-        Selection([Note("d'8"), Note("e'8")])
-        Selection([Note("d'8"), Note('a,4')])
-        Selection([Note('c4'), Note("e'8")])
-        Selection([Note('c4'), Note('a,4')])
-        Selection([Note("e'8"), Note('a,4')])
-        Selection([Note("e'8"), Note("f'8")])
-        Selection([Note('a,4'), Note("f'8")])
-        Selection([Note("f'8"), Note("g'4")])
-        Selection([Note("f'8"), Note('g,4')])
-        Selection([Note('a,4'), Note("g'4")])
-        Selection([Note('a,4'), Note('g,4')])
-        Selection([Note("g'4"), Note('g,4')])
+        [Note("c'8"), Note('c4')]
+        [Note("c'8"), Note("d'8")]
+        [Note('c4'), Note("d'8")]
+        [Note("d'8"), Note("e'8")]
+        [Note("d'8"), Note('a,4')]
+        [Note('c4'), Note("e'8")]
+        [Note('c4'), Note('a,4')]
+        [Note("e'8"), Note('a,4')]
+        [Note("e'8"), Note("f'8")]
+        [Note('a,4'), Note("f'8")]
+        [Note("f'8"), Note("g'4")]
+        [Note("f'8"), Note('g,4')]
+        [Note('a,4'), Note("g'4")]
+        [Note('a,4'), Note('g,4')]
+        [Note("g'4"), Note('g,4')]
 
     Iterates leaf pairs left-to-right and top-to-bottom.
 
     Returns generator.
     """
     vertical_moments = iterate_vertical_moments(components)
-    for moment_1, moment_2 in _sequence.Sequence(vertical_moments).nwise():
+    for moment_1, moment_2 in _sequence.nwise(vertical_moments):
         for pair in _enumerate.yield_pairs(moment_1.start_leaves):
-            yield _selection.Selection(pair)
+            yield list(pair)
         sequences = [moment_1.leaves, moment_2.start_leaves]
         for pair in _enumerate.outer_product(sequences):
-            yield _selection.Selection(pair)
+            yield list(pair)
     else:
         for pair in _enumerate.yield_pairs(moment_2.start_leaves):
-            yield _selection.Selection(pair)
+            yield list(pair)
 
 
 def iterate_pitch_pairs(components):
@@ -776,21 +773,21 @@ def iterate_pitch_pairs(components):
 
         >>> for pair in abjad.iterate_pitch_pairs(score):
         ...     pair
-        PitchSegment("c' c")
-        PitchSegment("c' d'")
-        PitchSegment("c d'")
-        PitchSegment("d' e'")
-        PitchSegment("d' a,")
-        PitchSegment("c e'")
-        PitchSegment("c a,")
-        PitchSegment("e' a,")
-        PitchSegment("e' f'")
-        PitchSegment("a, f'")
-        PitchSegment("f' g'")
-        PitchSegment("f' g,")
-        PitchSegment("a, g'")
-        PitchSegment("a, g,")
-        PitchSegment("g' g,")
+        PitchSegment(items="c' c", item_class=NamedPitch)
+        PitchSegment(items="c' d'", item_class=NamedPitch)
+        PitchSegment(items="c d'", item_class=NamedPitch)
+        PitchSegment(items="d' e'", item_class=NamedPitch)
+        PitchSegment(items="d' a,", item_class=NamedPitch)
+        PitchSegment(items="c e'", item_class=NamedPitch)
+        PitchSegment(items="c a,", item_class=NamedPitch)
+        PitchSegment(items="e' a,", item_class=NamedPitch)
+        PitchSegment(items="e' f'", item_class=NamedPitch)
+        PitchSegment(items="a, f'", item_class=NamedPitch)
+        PitchSegment(items="f' g'", item_class=NamedPitch)
+        PitchSegment(items="f' g,", item_class=NamedPitch)
+        PitchSegment(items="a, g'", item_class=NamedPitch)
+        PitchSegment(items="a, g,", item_class=NamedPitch)
+        PitchSegment(items="g' g,", item_class=NamedPitch)
 
     ..  container:: example
 
@@ -811,33 +808,33 @@ def iterate_pitch_pairs(components):
         >>> for pair in abjad.iterate_pitch_pairs(staff):
         ...     pair
         ...
-        PitchSegment("c' d'")
-        PitchSegment("c' e'")
-        PitchSegment("d' e'")
-        PitchSegment("c' f''")
-        PitchSegment("c' g''")
-        PitchSegment("d' f''")
-        PitchSegment("d' g''")
-        PitchSegment("e' f''")
-        PitchSegment("e' g''")
-        PitchSegment("f'' g''")
+        PitchSegment(items="c' d'", item_class=NamedPitch)
+        PitchSegment(items="c' e'", item_class=NamedPitch)
+        PitchSegment(items="d' e'", item_class=NamedPitch)
+        PitchSegment(items="c' f''", item_class=NamedPitch)
+        PitchSegment(items="c' g''", item_class=NamedPitch)
+        PitchSegment(items="d' f''", item_class=NamedPitch)
+        PitchSegment(items="d' g''", item_class=NamedPitch)
+        PitchSegment(items="e' f''", item_class=NamedPitch)
+        PitchSegment(items="e' g''", item_class=NamedPitch)
+        PitchSegment(items="f'' g''", item_class=NamedPitch)
 
     Returns generator.
     """
     for leaf_pair in iterate_leaf_pairs(components):
         pitches = sorted(iterate_.pitches(leaf_pair[0]))
         for pair in _enumerate.yield_pairs(pitches):
-            yield _pitch.PitchSegment(pair)
+            yield _pcollections.PitchSegment(pair)
         if isinstance(leaf_pair, set):
             pitches = sorted(iterate_.pitches(leaf_pair))
             for pair in _enumerate.yield_pairs(pitches):
-                yield _pitch.PitchSegment(pair)
+                yield _pcollections.PitchSegment(pair)
         else:
             pitches_1 = sorted(iterate_.pitches(leaf_pair[0]))
             pitches_2 = sorted(iterate_.pitches(leaf_pair[1]))
             sequences = [pitches_1, pitches_2]
             for pair in _enumerate.outer_product(sequences):
-                yield _pitch.PitchSegment(pair)
+                yield _pcollections.PitchSegment(pair)
         pitches = sorted(iterate_.pitches(leaf_pair[1]))
         for pair in _enumerate.yield_pairs(pitches):
-            yield _pitch.PitchSegment(pair)
+            yield _pcollections.PitchSegment(pair)
