@@ -171,7 +171,7 @@ def check_duplicate_ids(argument) -> typing.Tuple[typing.List, int]:
     violators = []
     components = iterate_.components(argument)
     total_ids = [id(_) for _ in components]
-    unique_ids = _sequence.Sequence(total_ids).remove_repeats()
+    unique_ids = _sequence.remove_repeats(total_ids)
     if len(unique_ids) < len(total_ids):
         for current_id in unique_ids:
             if 1 < total_ids.count(current_id):
